@@ -25,6 +25,7 @@
 #include <string.h>
 #include <glib/gstdio.h>
 #include <config.h>
+#include <string.h>
 
 
 #define VALA_TYPE_PROJECT_TYPE (vala_project_type_get_type ())
@@ -58,11 +59,13 @@ struct _ValaProjectGenerator {
 	GtkDialog parent_instance;
 	ValaProjectGeneratorPrivate * priv;
 };
+
 struct _ValaProjectGeneratorClass {
 	GtkDialogClass parent_class;
 };
 
 
+
 GType vala_project_type_get_type (void);
 GType vala_project_license_get_type (void);
 struct _ValaProjectGeneratorPrivate {
@@ -81,6 +84,7 @@ struct _ValaProjectGeneratorPrivate {
 	ValaProjectType project_type;
 	ValaProjectLicense project_license;
 };
+
 #define VALA_PROJECT_GENERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROJECT_GENERATOR, ValaProjectGeneratorPrivate))
 enum  {
 	VALA_PROJECT_GENERATOR_DUMMY_PROPERTY
@@ -145,17 +149,18 @@ static GtkHBox* vala_project_generator_create_hbox (ValaProjectGenerator* self,
 	float _tmp1;
 	GtkHBox* _tmp2;
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
-	g_return_val_if_fail (size_group == NULL || GTK_IS_SIZE_GROUP (size_group), NULL);
+	g_return_val_if_fail (title != NULL, NULL);
+	g_return_val_if_fail (GTK_IS_SIZE_GROUP (size_group), NULL);
 	hbox = g_object_ref_sink (gtk_hbox_new (FALSE, 6));
-	gtk_box_pack_start (GTK_BOX ((GTK_VBOX (GTK_DIALOG (self)->vbox))), GTK_WIDGET (hbox), FALSE, FALSE, ((guint) 0));
+	gtk_box_pack_start (GTK_BOX ((GTK_VBOX (GTK_DIALOG (self)->vbox))), GTK_WIDGET (hbox), FALSE, FALSE, ((guint) (0)));
 	gtk_widget_show (GTK_WIDGET (hbox));
 	label = g_object_ref_sink (gtk_label_new ("    "));
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 	gtk_widget_show (GTK_WIDGET (label));
 	_tmp0 = NULL;
 	label = (_tmp0 = g_object_ref_sink (gtk_label_new (title)), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0);
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
-	g_object_set (GTK_MISC (label), "xalign", ((float) 0), NULL);
+	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
+	g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 	gtk_widget_show (GTK_WIDGET (label));
 	gtk_size_group_add_widget (size_group, GTK_WIDGET (label));
 	_tmp2 = NULL;
@@ -200,7 +205,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < g_utf8_strlen (self->priv->project_name, -1); i++) {
+		for (; i < g_utf8_strlen (self->priv->project_name, -1); i++) {
 			gunichar c;
 			c = g_utf8_get_char (g_utf8_offset_to_pointer (self->priv->project_name, i));
 			if ((c >= 'a' && c <= 'z') || (c >= 'A' && c <= 'Z') || (c >= '0' && c <= '9')) {
@@ -209,8 +214,8 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 				g_string_append_unichar (namespace_name_str, c);
 			} else {
 				if (c == '-' || c == ' ') {
-					g_string_append_unichar (project_name_str, ((gunichar) '-'));
-					g_string_append_unichar (make_name_str, ((gunichar) '_'));
+					g_string_append_unichar (project_name_str, ((gunichar) ('-')));
+					g_string_append_unichar (make_name_str, ((gunichar) ('_')));
 				}
 			}
 		}
@@ -224,17 +229,17 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 	_tmp7 = NULL;
 	_tmp6 = NULL;
 	_tmp5 = NULL;
-	self->priv->namespace_name = (_tmp10 = g_strconcat ((_tmp7 = g_utf8_strup ((_tmp6 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) 0)), g_strndup (_tmp6, g_utf8_offset_to_pointer (_tmp6, ((glong) 1)) - _tmp6)), -1)), (_tmp9 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) 1)), g_strndup (_tmp9, g_utf8_offset_to_pointer (_tmp9, g_utf8_strlen (namespace_name_str->str, -1) - 1) - _tmp9)), NULL), (self->priv->namespace_name = (g_free (self->priv->namespace_name), NULL)), _tmp10);
-	_tmp8 = (g_free (_tmp8), NULL);
+	self->priv->namespace_name = (_tmp10 = g_strconcat ((_tmp7 = g_utf8_strup ((_tmp6 = (_tmp5 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) (0))), g_strndup (_tmp5, g_utf8_offset_to_pointer (_tmp5, ((glong) (1))) - _tmp5))), -1)), (_tmp9 = (_tmp8 = g_utf8_offset_to_pointer (namespace_name_str->str, ((glong) (1))), g_strndup (_tmp8, g_utf8_offset_to_pointer (_tmp8, g_utf8_strlen (namespace_name_str->str, -1) - 1) - _tmp8))), NULL), (self->priv->namespace_name = (g_free (self->priv->namespace_name), NULL)), _tmp10);
+	_tmp9 = (g_free (_tmp9), NULL);
 	_tmp7 = (g_free (_tmp7), NULL);
-	_tmp5 = (g_free (_tmp5), NULL);
+	_tmp6 = (g_free (_tmp6), NULL);
 	_tmp12 = NULL;
 	_tmp11 = NULL;
 	self->priv->make_name = (_tmp12 = (_tmp11 = make_name_str->str, (_tmp11 == NULL ? NULL : g_strdup (_tmp11))), (self->priv->make_name = (g_free (self->priv->make_name), NULL)), _tmp12);
 	_tmp13 = NULL;
 	self->priv->upper_case_make_name = (_tmp13 = g_utf8_strup (self->priv->make_name, -1), (self->priv->upper_case_make_name = (g_free (self->priv->upper_case_make_name), NULL)), _tmp13);
-	self->priv->project_type = ((ValaProjectType) gtk_combo_box_get_active (self->priv->project_type_combobox));
-	self->priv->project_license = ((ValaProjectLicense) gtk_combo_box_get_active (self->priv->license_combobox));
+	self->priv->project_type = ((ValaProjectType) (gtk_combo_box_get_active (self->priv->project_type_combobox)));
+	self->priv->project_license = ((ValaProjectLicense) (gtk_combo_box_get_active (self->priv->license_combobox)));
 	_tmp15 = NULL;
 	_tmp14 = NULL;
 	self->priv->real_name = (_tmp15 = (_tmp14 = gtk_entry_get_text (self->priv->name_entry), (_tmp14 == NULL ? NULL : g_strdup (_tmp14))), (self->priv->real_name = (g_free (self->priv->real_name), NULL)), _tmp15);
@@ -335,7 +340,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 			g_clear_error (&inner_error);
 		}
 		_tmp20 = NULL;
-		g_file_set_contents ((_tmp20 = g_strconcat (self->priv->project_path, "/NEWS", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp20 = g_strconcat (self->priv->project_path, "/NEWS", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -345,7 +350,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		}
 		_tmp20 = (g_free (_tmp20), NULL);
 		_tmp21 = NULL;
-		g_file_set_contents ((_tmp21 = g_strconcat (self->priv->project_path, "/README", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp21 = g_strconcat (self->priv->project_path, "/README", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -355,7 +360,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		}
 		_tmp21 = (g_free (_tmp21), NULL);
 		_tmp22 = NULL;
-		g_file_set_contents ((_tmp22 = g_strconcat (self->priv->project_path, "/ChangeLog", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp22 = g_strconcat (self->priv->project_path, "/ChangeLog", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -365,7 +370,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		}
 		_tmp22 = (g_free (_tmp22), NULL);
 		_tmp23 = NULL;
-		g_file_set_contents ((_tmp23 = g_strconcat (self->priv->project_path, "/po/ChangeLog", NULL)), "", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp23 = g_strconcat (self->priv->project_path, "/po/ChangeLog", NULL)), "", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
 				goto __catch0_g_file_error;
@@ -380,13 +385,14 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 			char* install_filename;
 			install_filename = g_strconcat (automake_path, "/INSTALL", NULL);
 			if (g_file_test (install_filename, G_FILE_TEST_EXISTS)) {
+				char* _tmp26;
 				gboolean _tmp25;
 				char* _tmp24;
-				char* _tmp26;
+				char* _tmp27;
+				_tmp26 = NULL;
 				_tmp24 = NULL;
 				_tmp25 = g_file_get_contents (install_filename, &_tmp24, NULL, &inner_error);
-				(s = (g_free (s), NULL));
-				s = _tmp24;
+				s = (_tmp26 = _tmp24, (s = (g_free (s), NULL)), _tmp26);
 				_tmp25;
 				if (inner_error != NULL) {
 					if (inner_error->domain == G_FILE_ERROR) {
@@ -395,8 +401,8 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 					g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 					g_clear_error (&inner_error);
 				}
-				_tmp26 = NULL;
-				g_file_set_contents ((_tmp26 = g_strconcat (self->priv->project_path, "/INSTALL", NULL)), s, ((glong) -1), &inner_error);
+				_tmp27 = NULL;
+				g_file_set_contents ((_tmp27 = g_strconcat (self->priv->project_path, "/INSTALL", NULL)), s, ((glong) (-1)), &inner_error);
 				if (inner_error != NULL) {
 					if (inner_error->domain == G_FILE_ERROR) {
 						goto __catch0_g_file_error;
@@ -404,63 +410,64 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 					g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 					g_clear_error (&inner_error);
 				}
-				_tmp26 = (g_free (_tmp26), NULL);
+				_tmp27 = (g_free (_tmp27), NULL);
 			}
 			install_filename = (g_free (install_filename), NULL);
 		}
 		license_filename = NULL;
 		if (self->priv->project_license == VALA_PROJECT_LICENSE_GPL2) {
-			char* _tmp27;
-			_tmp27 = NULL;
-			license_filename = (_tmp27 = g_strconcat (PACKAGE_DATADIR, "/licenses/gpl-2.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp27);
+			char* _tmp28;
+			_tmp28 = NULL;
+			license_filename = (_tmp28 = g_strconcat (PACKAGE_DATADIR, "/licenses/gpl-2.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp28);
 			if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-				char* _tmp28;
-				_tmp28 = NULL;
-				license_filename = (_tmp28 = g_strdup ("/usr/share/common-licenses/GPL-2"), (license_filename = (g_free (license_filename), NULL)), _tmp28);
+				char* _tmp29;
+				_tmp29 = NULL;
+				license_filename = (_tmp29 = g_strdup ("/usr/share/common-licenses/GPL-2"), (license_filename = (g_free (license_filename), NULL)), _tmp29);
 			}
 		} else {
 			if (self->priv->project_license == VALA_PROJECT_LICENSE_LGPL2) {
-				char* _tmp29;
-				_tmp29 = NULL;
-				license_filename = (_tmp29 = g_strconcat (PACKAGE_DATADIR, "/licenses/lgpl-2.1.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp29);
+				char* _tmp30;
+				_tmp30 = NULL;
+				license_filename = (_tmp30 = g_strconcat (PACKAGE_DATADIR, "/licenses/lgpl-2.1.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp30);
 				if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-					char* _tmp30;
-					_tmp30 = NULL;
-					license_filename = (_tmp30 = g_strdup ("/usr/share/common-licenses/LGPL-2.1"), (license_filename = (g_free (license_filename), NULL)), _tmp30);
+					char* _tmp31;
+					_tmp31 = NULL;
+					license_filename = (_tmp31 = g_strdup ("/usr/share/common-licenses/LGPL-2.1"), (license_filename = (g_free (license_filename), NULL)), _tmp31);
 				}
 			} else {
 				if (self->priv->project_license == VALA_PROJECT_LICENSE_GPL3) {
-					char* _tmp31;
-					_tmp31 = NULL;
-					license_filename = (_tmp31 = g_strconcat (PACKAGE_DATADIR, "/licenses/gpl-3.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp31);
+					char* _tmp32;
+					_tmp32 = NULL;
+					license_filename = (_tmp32 = g_strconcat (PACKAGE_DATADIR, "/licenses/gpl-3.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp32);
 					if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-						char* _tmp32;
-						_tmp32 = NULL;
-						license_filename = (_tmp32 = g_strdup ("/usr/share/common-licenses/GPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp32);
+						char* _tmp33;
+						_tmp33 = NULL;
+						license_filename = (_tmp33 = g_strdup ("/usr/share/common-licenses/GPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp33);
 					}
 				} else {
 					if (self->priv->project_license == VALA_PROJECT_LICENSE_LGPL3) {
-						char* _tmp33;
-						_tmp33 = NULL;
-						license_filename = (_tmp33 = g_strconcat (PACKAGE_DATADIR, "/licenses/lgpl-3.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp33);
+						char* _tmp34;
+						_tmp34 = NULL;
+						license_filename = (_tmp34 = g_strconcat (PACKAGE_DATADIR, "/licenses/lgpl-3.0.txt", NULL), (license_filename = (g_free (license_filename), NULL)), _tmp34);
 						if (!g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-							char* _tmp34;
-							_tmp34 = NULL;
-							license_filename = (_tmp34 = g_strdup ("/usr/share/common-licenses/LGPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp34);
+							char* _tmp35;
+							_tmp35 = NULL;
+							license_filename = (_tmp35 = g_strdup ("/usr/share/common-licenses/LGPL-3"), (license_filename = (g_free (license_filename), NULL)), _tmp35);
 						}
 					}
 				}
 			}
 		}
 		if (license_filename != NULL && g_file_test (license_filename, G_FILE_TEST_EXISTS)) {
-			gboolean _tmp36;
-			char* _tmp35;
-			char* _tmp37;
-			_tmp35 = NULL;
-			_tmp36 = g_file_get_contents (license_filename, &_tmp35, NULL, &inner_error);
-			(s = (g_free (s), NULL));
-			s = _tmp35;
-			_tmp36;
+			char* _tmp38;
+			gboolean _tmp37;
+			char* _tmp36;
+			char* _tmp39;
+			_tmp38 = NULL;
+			_tmp36 = NULL;
+			_tmp37 = g_file_get_contents (license_filename, &_tmp36, NULL, &inner_error);
+			s = (_tmp38 = _tmp36, (s = (g_free (s), NULL)), _tmp38);
+			_tmp37;
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
@@ -468,8 +475,8 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 				g_clear_error (&inner_error);
 			}
-			_tmp37 = NULL;
-			g_file_set_contents ((_tmp37 = g_strconcat (self->priv->project_path, "/COPYING", NULL)), s, ((glong) -1), &inner_error);
+			_tmp39 = NULL;
+			g_file_set_contents ((_tmp39 = g_strconcat (self->priv->project_path, "/COPYING", NULL)), s, ((glong) (-1)), &inner_error);
 			if (inner_error != NULL) {
 				if (inner_error->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
@@ -477,7 +484,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 				g_clear_error (&inner_error);
 			}
-			_tmp37 = (g_free (_tmp37), NULL);
+			_tmp39 = (g_free (_tmp39), NULL);
 		}
 		s = (g_free (s), NULL);
 		automake_path = (g_free (automake_path), NULL);
@@ -516,7 +523,7 @@ static void vala_project_generator_write_autogen_sh (ValaProjectGenerator* self,
 	g_string_append_printf (s, "PKG_NAME=\"%s\"\n\n", self->priv->project_name);
 	g_string_append (s, ". gnome-autogen.sh\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/autogen.sh", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/autogen.sh", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -574,7 +581,7 @@ static void vala_project_generator_write_configure_ac (ValaProjectGenerator* sel
 	g_string_append (s, "\tpo/Makefile.in])\n\n");
 	g_string_append (s, "AC_OUTPUT\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/configure.ac", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/configure.ac", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -639,7 +646,7 @@ static void vala_project_generator_write_makefile_am (ValaProjectGenerator* self
 	g_string_append (s, "\tpo/.intltool-merge-cache \\\n");
 	g_string_append (s, "\t$(NULL)\n\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/Makefile.am", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/Makefile.am", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -652,73 +659,75 @@ static void vala_project_generator_write_makefile_am (ValaProjectGenerator* self
 static char* vala_project_generator_generate_source_file_header (ValaProjectGenerator* self, const char* filename) {
 	GString* s;
 	GTimeVal tv = {0};
-	GDate* d;
+	GDate _tmp0 = {0};
+	GDate d;
 	char* license_name;
 	char* license_version;
 	char* program_type;
-	ValaProjectLicense _tmp12;
-	const char* _tmp13;
-	char* _tmp14;
+	ValaProjectLicense _tmp13;
+	const char* _tmp14;
+	char* _tmp15;
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
+	g_return_val_if_fail (filename != NULL, NULL);
 	s = g_string_new ("");
 	g_get_current_time (&tv);
-	d = g_date_new ();
-	g_date_set_time_val (d, &tv);
+	d = (memset (&_tmp0, 0, sizeof (GDate)), _tmp0);
+	g_date_set_time_val (&d, &tv);
 	g_string_append_printf (s, "/* %s\n", filename);
 	g_string_append (s, " *\n");
-	g_string_append_printf (s, " * Copyright (C) %d  %s\n", g_date_get_year (d), self->priv->real_name);
+	g_string_append_printf (s, " * Copyright (C) %d  %s\n", g_date_get_year (&d), self->priv->real_name);
 	g_string_append (s, " *\n");
 	license_name = g_strdup ("");
 	license_version = NULL;
 	program_type = NULL;
-	_tmp12 = self->priv->project_license;
-	if (_tmp12 == VALA_PROJECT_LICENSE_GPL2)
+	_tmp13 = self->priv->project_license;
+	if (_tmp13 == VALA_PROJECT_LICENSE_GPL2)
 	do {
-		char* _tmp0;
 		char* _tmp1;
 		char* _tmp2;
-		_tmp0 = NULL;
-		license_name = (_tmp0 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp0);
-		_tmp1 = NULL;
-		license_version = (_tmp1 = g_strdup ("2"), (license_version = (g_free (license_version), NULL)), _tmp1);
-		_tmp2 = NULL;
-		program_type = (_tmp2 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp2);
-		break;
-	} while (0); else if (_tmp12 == VALA_PROJECT_LICENSE_GPL3)
-	do {
 		char* _tmp3;
+		_tmp1 = NULL;
+		license_name = (_tmp1 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp1);
+		_tmp2 = NULL;
+		license_version = (_tmp2 = g_strdup ("2"), (license_version = (g_free (license_version), NULL)), _tmp2);
+		_tmp3 = NULL;
+		program_type = (_tmp3 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp3);
+		break;
+	} while (0); else if (_tmp13 == VALA_PROJECT_LICENSE_GPL3)
+	do {
 		char* _tmp4;
 		char* _tmp5;
-		_tmp3 = NULL;
-		license_name = (_tmp3 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp3);
-		_tmp4 = NULL;
-		license_version = (_tmp4 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp4);
-		_tmp5 = NULL;
-		program_type = (_tmp5 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp5);
-		break;
-	} while (0); else if (_tmp12 == VALA_PROJECT_LICENSE_LGPL2)
-	do {
 		char* _tmp6;
+		_tmp4 = NULL;
+		license_name = (_tmp4 = g_strdup ("GNU General Public License"), (license_name = (g_free (license_name), NULL)), _tmp4);
+		_tmp5 = NULL;
+		license_version = (_tmp5 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp5);
+		_tmp6 = NULL;
+		program_type = (_tmp6 = g_strdup ("program"), (program_type = (g_free (program_type), NULL)), _tmp6);
+		break;
+	} while (0); else if (_tmp13 == VALA_PROJECT_LICENSE_LGPL2)
+	do {
 		char* _tmp7;
 		char* _tmp8;
-		_tmp6 = NULL;
-		license_name = (_tmp6 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp6);
-		_tmp7 = NULL;
-		license_version = (_tmp7 = g_strdup ("2.1"), (license_version = (g_free (license_version), NULL)), _tmp7);
-		_tmp8 = NULL;
-		program_type = (_tmp8 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp8);
-		break;
-	} while (0); else if (_tmp12 == VALA_PROJECT_LICENSE_LGPL3)
-	do {
 		char* _tmp9;
+		_tmp7 = NULL;
+		license_name = (_tmp7 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp7);
+		_tmp8 = NULL;
+		license_version = (_tmp8 = g_strdup ("2.1"), (license_version = (g_free (license_version), NULL)), _tmp8);
+		_tmp9 = NULL;
+		program_type = (_tmp9 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp9);
+		break;
+	} while (0); else if (_tmp13 == VALA_PROJECT_LICENSE_LGPL3)
+	do {
 		char* _tmp10;
 		char* _tmp11;
-		_tmp9 = NULL;
-		license_name = (_tmp9 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp9);
+		char* _tmp12;
 		_tmp10 = NULL;
-		license_version = (_tmp10 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp10);
+		license_name = (_tmp10 = g_strdup ("GNU Lesser General Public License"), (license_name = (g_free (license_name), NULL)), _tmp10);
 		_tmp11 = NULL;
-		program_type = (_tmp11 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp11);
+		license_version = (_tmp11 = g_strdup ("3"), (license_version = (g_free (license_version), NULL)), _tmp11);
+		_tmp12 = NULL;
+		program_type = (_tmp12 = g_strdup ("library"), (program_type = (g_free (program_type), NULL)), _tmp12);
 		break;
 	} while (0);
 	g_string_append_printf (s, " * This %s is free software: you can redistribute it and/or modify\n", program_type);
@@ -737,9 +746,9 @@ static char* vala_project_generator_generate_source_file_header (ValaProjectGene
 	g_string_append (s, " * Author:\n");
 	g_string_append_printf (s, " * \t%s <%s>\n", self->priv->real_name, self->priv->email_address);
 	g_string_append (s, " */\n\n");
-	_tmp13 = NULL;
 	_tmp14 = NULL;
-	return (_tmp14 = (_tmp13 = s->str, (_tmp13 == NULL ? NULL : g_strdup (_tmp13))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), (d == NULL ? NULL : (d = (g_date_free (d), NULL))), (license_name = (g_free (license_name), NULL)), (license_version = (g_free (license_version), NULL)), (program_type = (g_free (program_type), NULL)), _tmp14);
+	_tmp15 = NULL;
+	return (_tmp15 = (_tmp14 = s->str, (_tmp14 == NULL ? NULL : g_strdup (_tmp14))), (s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL))), (license_name = (g_free (license_name), NULL)), (license_version = (g_free (license_version), NULL)), (program_type = (g_free (program_type), NULL)), _tmp15);
 }
 
 
@@ -772,7 +781,7 @@ static void vala_project_generator_write_main_vala (ValaProjectGenerator* self,
 	g_string_append (s, "\n");
 	g_string_append (s, "}\n");
 	_tmp1 = NULL;
-	g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/src/main.vala", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/src/main.vala", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -883,7 +892,7 @@ static void vala_project_generator_write_mainwindow_vala (ValaProjectGenerator*
 	g_string_append (s, "\n");
 	g_string_append (s, "}\n");
 	_tmp2 = NULL;
-	g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/src/mainwindow.vala", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/src/mainwindow.vala", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -910,7 +919,7 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 		g_string_append (s, "src/main.vala\n");
 	}
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/POTFILES.in", NULL)), s->str, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/POTFILES.in", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -919,7 +928,7 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 	if (use_gtk) {
 		char* _tmp1;
 		_tmp1 = NULL;
-		g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/mainwindow.c\n", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/mainwindow.c\n", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			g_propagate_error (error, inner_error);
 			return;
@@ -928,7 +937,7 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 	} else {
 		char* _tmp2;
 		_tmp2 = NULL;
-		g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/main.c\n", ((glong) -1), &inner_error);
+		g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/main.c\n", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			g_propagate_error (error, inner_error);
 			return;
@@ -947,7 +956,7 @@ static void vala_project_generator_write_linguas (ValaProjectGenerator* self, GE
 	inner_error = NULL;
 	s = g_strdup ("# please keep this list sorted alphabetically\n#\n");
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/LINGUAS", NULL)), s, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/LINGUAS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -965,7 +974,7 @@ static void vala_project_generator_write_authors (ValaProjectGenerator* self, GE
 	inner_error = NULL;
 	s = g_strdup_printf ("%s <%s>\n", self->priv->real_name, self->priv->email_address);
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/AUTHORS", NULL)), s, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/AUTHORS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -983,7 +992,7 @@ static void vala_project_generator_write_maintainers (ValaProjectGenerator* self
 	inner_error = NULL;
 	s = g_strdup_printf ("%s\nE-mail: %s\n", self->priv->real_name, self->priv->email_address);
 	_tmp0 = NULL;
-	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/MAINTAINERS", NULL)), s, ((glong) -1), &inner_error);
+	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/MAINTAINERS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
 		return;
@@ -998,15 +1007,17 @@ static char* vala_project_generator_get_automake_path (ValaProjectGenerator* sel
 	gint automake_paths_length1;
 	char** _tmp0;
 	char** automake_paths;
-	gpointer _tmp4;
+	char* _tmp4;
 	g_return_val_if_fail (VALA_IS_PROJECT_GENERATOR (self), NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	automake_paths = (_tmp1 = (_tmp0 = g_new0 (char*, 3 + 1), _tmp0[0] = g_strdup ("/usr/share/automake"), _tmp0[1] = g_strdup ("/usr/share/automake-1.10"), _tmp0[2] = g_strdup ("/usr/share/automake-1.9"), _tmp0), automake_paths_length1 = 3, _tmp1);
 	{
 		char** automake_path_collection;
+		int automake_path_collection_length1;
 		int automake_path_it;
 		automake_path_collection = automake_paths;
+		automake_path_collection_length1 = automake_paths_length1;
 		for (automake_path_it = 0; (automake_paths_length1 != -1 && automake_path_it < automake_paths_length1) || (automake_paths_length1 == -1 && automake_path_collection[automake_path_it] != NULL); automake_path_it = automake_path_it + 1) {
 			const char* _tmp3;
 			char* automake_path;
@@ -1016,13 +1027,14 @@ static char* vala_project_generator_get_automake_path (ValaProjectGenerator* sel
 				if (g_file_test (automake_path, G_FILE_TEST_IS_DIR)) {
 					char* _tmp2;
 					_tmp2 = NULL;
-					return (_tmp2 = automake_path, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) g_free)), NULL)), _tmp2);
+					return (_tmp2 = automake_path, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) (g_free))), NULL)), _tmp2);
 				}
 				automake_path = (g_free (automake_path), NULL);
 			}
 		}
 	}
-	return (_tmp4 = NULL, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) g_free)), NULL)), _tmp4);
+	_tmp4 = NULL;
+	return (_tmp4 = NULL, (automake_paths = (_vala_array_free (automake_paths, automake_paths_length1, ((GDestroyNotify) (g_free))), NULL)), _tmp4);
 }
 
 
@@ -1079,7 +1091,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		const char* _tmp17;
 		GtkWidget* _tmp19;
 		GtkWidget* ok_button;
-		gtk_container_set_border_width (GTK_CONTAINER (self), ((guint) 12));
+		gtk_container_set_border_width (GTK_CONTAINER (self), ((guint) (12)));
 		gtk_dialog_set_has_separator (GTK_DIALOG (self), FALSE);
 		_tmp0 = NULL;
 		vbox = (_tmp0 = GTK_VBOX (GTK_DIALOG (self)->vbox), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
@@ -1089,47 +1101,47 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		gtk_box_set_spacing (GTK_BOX (vbox), 6);
 		_tmp1 = NULL;
 		label = (_tmp1 = g_object_ref_sink (gtk_label_new ("<b>Project</b>")), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp1);
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 		gtk_label_set_use_markup (label, TRUE);
-		g_object_set (GTK_MISC (label), "xalign", ((float) 0), NULL);
+		g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 		gtk_widget_show (GTK_WIDGET (label));
 		_tmp3 = NULL;
 		hbox = (_tmp3 = vala_project_generator_create_hbox (self, "Project folder:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp3);
 		_tmp4 = NULL;
 		self->priv->project_folder_button = (_tmp4 = g_object_ref_sink (gtk_file_chooser_button_new ("Select a project folder", GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER)), (self->priv->project_folder_button == NULL ? NULL : (self->priv->project_folder_button = (g_object_unref (self->priv->project_folder_button), NULL))), _tmp4);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_folder_button), TRUE, TRUE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_folder_button), TRUE, TRUE, ((guint) (0)));
 		gtk_widget_show (GTK_WIDGET (self->priv->project_folder_button));
 		_tmp5 = NULL;
 		hbox = (_tmp5 = vala_project_generator_create_hbox (self, "Project type:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp5);
 		_tmp6 = NULL;
 		self->priv->project_type_combobox = (_tmp6 = g_object_ref_sink (gtk_combo_box_new_text ()), (self->priv->project_type_combobox == NULL ? NULL : (self->priv->project_type_combobox = (g_object_unref (self->priv->project_type_combobox), NULL))), _tmp6);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_type_combobox), TRUE, TRUE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->project_type_combobox), TRUE, TRUE, ((guint) (0)));
 		gtk_combo_box_append_text (self->priv->project_type_combobox, "Console Application");
 		gtk_combo_box_append_text (self->priv->project_type_combobox, "GTK+ Application");
-		gtk_combo_box_set_active (self->priv->project_type_combobox, ((gint) VALA_PROJECT_TYPE_GTK_APPLICATION));
+		gtk_combo_box_set_active (self->priv->project_type_combobox, ((gint) (VALA_PROJECT_TYPE_GTK_APPLICATION)));
 		gtk_widget_show (GTK_WIDGET (self->priv->project_type_combobox));
 		_tmp7 = NULL;
 		hbox = (_tmp7 = vala_project_generator_create_hbox (self, "License:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp7);
 		_tmp8 = NULL;
 		self->priv->license_combobox = (_tmp8 = g_object_ref_sink (gtk_combo_box_new_text ()), (self->priv->license_combobox == NULL ? NULL : (self->priv->license_combobox = (g_object_unref (self->priv->license_combobox), NULL))), _tmp8);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->license_combobox), TRUE, TRUE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->license_combobox), TRUE, TRUE, ((guint) (0)));
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU General Public License, version 2 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU General Public License, version 3 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU Lesser General Public License, version 2.1 or later");
 		gtk_combo_box_append_text (self->priv->license_combobox, "GNU Lesser General Public License, version 3 or later");
-		gtk_combo_box_set_active (self->priv->license_combobox, ((gint) VALA_PROJECT_LICENSE_LGPL2));
+		gtk_combo_box_set_active (self->priv->license_combobox, ((gint) (VALA_PROJECT_LICENSE_LGPL2)));
 		gtk_widget_show (GTK_WIDGET (self->priv->license_combobox));
 		_tmp9 = NULL;
 		label = (_tmp9 = g_object_ref_sink (gtk_label_new ("<b>Author</b>")), (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp9);
-		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (label), FALSE, FALSE, ((guint) (0)));
 		gtk_label_set_use_markup (label, TRUE);
-		g_object_set (GTK_MISC (label), "xalign", ((float) 0), NULL);
+		g_object_set (GTK_MISC (label), "xalign", ((float) (0)), NULL);
 		gtk_widget_show (GTK_WIDGET (label));
 		_tmp11 = NULL;
 		hbox = (_tmp11 = vala_project_generator_create_hbox (self, "Name:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp11);
 		_tmp12 = NULL;
 		self->priv->name_entry = (_tmp12 = g_object_ref_sink (gtk_entry_new ()), (self->priv->name_entry == NULL ? NULL : (self->priv->name_entry = (g_object_unref (self->priv->name_entry), NULL))), _tmp12);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->name_entry), TRUE, TRUE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->name_entry), TRUE, TRUE, ((guint) (0)));
 		_tmp14 = NULL;
 		_tmp13 = NULL;
 		self->priv->real_name = (_tmp14 = (_tmp13 = g_getenv ("REAL_NAME"), (_tmp13 == NULL ? NULL : g_strdup (_tmp13))), (self->priv->real_name = (g_free (self->priv->real_name), NULL)), _tmp14);
@@ -1141,7 +1153,7 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 		hbox = (_tmp15 = vala_project_generator_create_hbox (self, "E-mail address:", size_group), (hbox == NULL ? NULL : (hbox = (g_object_unref (hbox), NULL))), _tmp15);
 		_tmp16 = NULL;
 		self->priv->email_entry = (_tmp16 = g_object_ref_sink (gtk_entry_new ()), (self->priv->email_entry == NULL ? NULL : (self->priv->email_entry = (g_object_unref (self->priv->email_entry), NULL))), _tmp16);
-		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->email_entry), TRUE, TRUE, ((guint) 0));
+		gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (self->priv->email_entry), TRUE, TRUE, ((guint) (0)));
 		_tmp18 = NULL;
 		_tmp17 = NULL;
 		self->priv->email_address = (_tmp18 = (_tmp17 = g_getenv ("EMAIL_ADDRESS"), (_tmp17 == NULL ? NULL : g_strdup (_tmp17))), (self->priv->email_address = (g_free (self->priv->email_address), NULL)), _tmp18);
@@ -1149,9 +1161,9 @@ static GObject * vala_project_generator_constructor (GType type, guint n_constru
 			gtk_entry_set_text (self->priv->email_entry, self->priv->email_address);
 		}
 		gtk_widget_show (GTK_WIDGET (self->priv->email_entry));
-		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CANCEL, ((gint) GTK_RESPONSE_CANCEL));
+		gtk_dialog_add_button (GTK_DIALOG (self), GTK_STOCK_CANCEL, ((gint) (GTK_RESPONSE_CANCEL)));
 		_tmp19 = NULL;
-		ok_button = (_tmp19 = gtk_dialog_add_button (GTK_DIALOG (self), "Create Project", ((gint) GTK_RESPONSE_OK)), (_tmp19 == NULL ? NULL : g_object_ref (_tmp19)));
+		ok_button = (_tmp19 = gtk_dialog_add_button (GTK_DIALOG (self), "Create Project", ((gint) (GTK_RESPONSE_OK))), (_tmp19 == NULL ? NULL : g_object_ref (_tmp19)));
 		gtk_widget_grab_default (ok_button);
 		(vbox == NULL ? NULL : (vbox = (g_object_unref (vbox), NULL)));
 		(size_group == NULL ? NULL : (size_group = (g_object_unref (size_group), NULL)));
@@ -1171,7 +1183,7 @@ static void vala_project_generator_class_init (ValaProjectGeneratorClass * klass
 }
 
 
-static void vala_project_generator_init (ValaProjectGenerator * self) {
+static void vala_project_generator_instance_init (ValaProjectGenerator * self) {
 	self->priv = VALA_PROJECT_GENERATOR_GET_PRIVATE (self);
 }
 
@@ -1198,7 +1210,7 @@ static void vala_project_generator_dispose (GObject * obj) {
 static GType vala_project_generator_get_type (void) {
 	static GType vala_project_generator_type_id = 0;
 	if (G_UNLIKELY (vala_project_generator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaProjectGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_project_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProjectGenerator), 0, (GInstanceInitFunc) vala_project_generator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaProjectGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_project_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProjectGenerator), 0, (GInstanceInitFunc) vala_project_generator_instance_init };
 		vala_project_generator_type_id = g_type_register_static (GTK_TYPE_DIALOG, "ValaProjectGenerator", &g_define_type_info, 0);
 	}
 	return vala_project_generator_type_id;
@@ -1210,12 +1222,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
