@@ -35,8 +35,8 @@
 #include <vala/valastruct.h>
 #include <vala/valapropertyaccessor.h>
 #include <vala/valasymbol.h>
-#include <gee/collection.h>
 #include <gee/list.h>
+#include <gee/collection.h>
 #include <vala/valapointertype.h>
 #include <vala/valaerrortype.h>
 #include <vala/valaformalparameter.h>
@@ -46,14 +46,14 @@
 
 
 enum  {
-	VALA_CCODE_TYPESYMBOL_BINDING_DUMMY_PROPERTY
+	VALA_CCODE_TYPE_SYMBOL_BINDING_DUMMY_PROPERTY
 };
-static gpointer vala_ccode_typesymbol_binding_parent_class = NULL;
+static gpointer vala_ccode_type_symbol_binding_parent_class = NULL;
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTypesymbolBinding* self, ValaProperty* prop) {
+ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_param_spec (ValaCCodeTypeSymbolBinding* self, ValaProperty* prop) {
 	ValaCCodeFunctionCall* cspec;
 	ValaCCodeConstant* _tmp0;
 	ValaCCodeConstant* _tmp2;
@@ -63,7 +63,7 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTy
 	char* pflags;
 	ValaCCodeConstant* _tmp81;
 	ValaCCodeFunctionCall* _tmp82;
-	g_return_val_if_fail (VALA_IS_CCODE_TYPESYMBOL_BINDING (self), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_TYPE_SYMBOL_BINDING (self), NULL);
 	g_return_val_if_fail (VALA_IS_PROPERTY (prop), NULL);
 	cspec = vala_ccode_function_call_new (NULL);
 	_tmp0 = NULL;
@@ -79,7 +79,7 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTy
 	vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp4 = vala_ccode_constant_new ((_tmp3 = g_strdup_printf ("\"%s\"", vala_property_get_blurb (prop)))))));
 	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
 	_tmp3 = (g_free (_tmp3), NULL);
-	if ((VALA_IS_CLASS (vala_data_type_get_data_type (vala_property_get_type_reference (prop))) && vala_typesymbol_is_subtype_of (VALA_TYPESYMBOL ((VALA_CLASS (vala_data_type_get_data_type (vala_property_get_type_reference (prop))))), vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->gobject_type)) || VALA_IS_INTERFACE (vala_data_type_get_data_type (vala_property_get_type_reference (prop)))) {
+	if ((VALA_IS_CLASS (vala_data_type_get_data_type (vala_property_get_property_type (prop))) && vala_typesymbol_is_subtype_of (VALA_TYPESYMBOL ((VALA_CLASS (vala_data_type_get_data_type (vala_property_get_property_type (prop))))), vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->gobject_type)) || VALA_IS_INTERFACE (vala_data_type_get_data_type (vala_property_get_property_type (prop)))) {
 		ValaCCodeIdentifier* _tmp5;
 		ValaCCodeIdentifier* _tmp7;
 		char* _tmp6;
@@ -88,11 +88,11 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTy
 		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 		_tmp7 = NULL;
 		_tmp6 = NULL;
-		vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type (vala_property_get_type_reference (prop)), "TYPE_"))))));
+		vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp7 = vala_ccode_identifier_new ((_tmp6 = vala_typesymbol_get_upper_case_cname (vala_data_type_get_data_type (vala_property_get_property_type (prop)), "TYPE_"))))));
 		(_tmp7 == NULL ? NULL : (_tmp7 = (g_object_unref (_tmp7), NULL)));
 		_tmp6 = (g_free (_tmp6), NULL);
 	} else {
-		if (vala_data_type_get_data_type (vala_property_get_type_reference (prop)) == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
+		if (vala_data_type_get_data_type (vala_property_get_property_type (prop)) == vala_data_type_get_data_type (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->string_type)) {
 			ValaCCodeIdentifier* _tmp8;
 			ValaCCodeConstant* _tmp9;
 			_tmp8 = NULL;
@@ -102,13 +102,13 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTy
 			vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_constant_new ("NULL"))));
 			(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
 		} else {
-			if (VALA_IS_ENUM (vala_data_type_get_data_type (vala_property_get_type_reference (prop)))) {
+			if (VALA_IS_ENUM (vala_data_type_get_data_type (vala_property_get_property_type (prop)))) {
 				ValaEnum* _tmp11;
-				ValaTypesymbol* _tmp10;
+				ValaTypeSymbol* _tmp10;
 				ValaEnum* e;
 				_tmp11 = NULL;
 				_tmp10 = NULL;
-				e = (_tmp11 = (_tmp10 = vala_data_type_get_data_type (vala_property_get_type_reference (prop)), (VALA_IS_ENUM (_tmp10) ? ((ValaEnum*) _tmp10) : NULL)), (_tmp11 == NULL ? NULL : g_object_ref (_tmp11)));
+				e = (_tmp11 = (_tmp10 = vala_data_type_get_data_type (vala_property_get_property_type (prop)), (VALA_IS_ENUM (_tmp10) ? ((ValaEnum*) (_tmp10)) : NULL)), (_tmp11 == NULL ? NULL : g_object_ref (_tmp11)));
 				if (vala_enum_get_has_type_id (e)) {
 					ValaCCodeIdentifier* _tmp15;
 					char* _tmp14;
@@ -164,19 +164,19 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTy
 					char* _tmp22;
 					_tmp23 = NULL;
 					_tmp22 = NULL;
-					vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_constant_new ((_tmp22 = vala_typesymbol_get_default_value (vala_data_type_get_data_type (vala_property_get_type_reference (prop))))))));
+					vala_ccode_function_call_add_argument (cspec, VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_constant_new ((_tmp22 = vala_typesymbol_get_default_value (vala_data_type_get_data_type (vala_property_get_property_type (prop))))))));
 					(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
 					_tmp22 = (g_free (_tmp22), NULL);
 				}
 				(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
 			} else {
-				if (VALA_IS_STRUCT (vala_data_type_get_data_type (vala_property_get_type_reference (prop)))) {
+				if (VALA_IS_STRUCT (vala_data_type_get_data_type (vala_property_get_property_type (prop)))) {
 					ValaStruct* _tmp24;
 					ValaStruct* st;
 					char* _tmp25;
 					gboolean _tmp26;
 					_tmp24 = NULL;
-					st = (_tmp24 = VALA_STRUCT (vala_data_type_get_data_type (vala_property_get_type_reference (prop))), (_tmp24 == NULL ? NULL : g_object_ref (_tmp24)));
+					st = (_tmp24 = VALA_STRUCT (vala_data_type_get_data_type (vala_property_get_property_type (prop))), (_tmp24 == NULL ? NULL : g_object_ref (_tmp24)));
 					_tmp25 = NULL;
 					if ((_tmp26 = _vala_strcmp0 ((_tmp25 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (st))), "G_TYPE_INT") == 0, (_tmp25 = (g_free (_tmp25), NULL)), _tmp26)) {
 						ValaCCodeIdentifier* _tmp27;
@@ -437,7 +437,7 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_param_spec (ValaCCodeTy
 }
 
 
-ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCCodeTypesymbolBinding* self, ValaSignal* sig, ValaTypesymbol* type) {
+ValaCCodeFunctionCall* vala_ccode_type_symbol_binding_get_signal_creation (ValaCCodeTypeSymbolBinding* self, ValaSignal* sig, ValaTypeSymbol* type) {
 	ValaCCodeIdentifier* _tmp0;
 	ValaCCodeFunctionCall* _tmp1;
 	ValaCCodeFunctionCall* csignew;
@@ -458,7 +458,7 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCC
 	ValaCCodeConstant* _tmp18;
 	char* _tmp17;
 	ValaCCodeFunctionCall* _tmp23;
-	g_return_val_if_fail (VALA_IS_CCODE_TYPESYMBOL_BINDING (self), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_TYPE_SYMBOL_BINDING (self), NULL);
 	g_return_val_if_fail (VALA_IS_SIGNAL (sig), NULL);
 	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type), NULL);
 	_tmp0 = NULL;
@@ -488,7 +488,7 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCC
 	(_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL)));
 	_tmp10 = NULL;
 	_tmp11 = NULL;
-	marshaller = (_tmp11 = vala_ccode_generator_get_marshaller_function (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), GEE_COLLECTION ((_tmp10 = vala_signal_get_parameters (sig))), vala_signal_get_return_type (sig), NULL), (_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL))), _tmp11);
+	marshaller = (_tmp11 = vala_ccode_generator_get_marshaller_function (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), (_tmp10 = vala_signal_get_parameters (sig)), vala_signal_get_return_type (sig), NULL, FALSE), (_tmp10 == NULL ? NULL : (_tmp10 = (g_object_unref (_tmp10), NULL))), _tmp11);
 	marshal_arg = vala_ccode_identifier_new (marshaller);
 	vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION (marshal_arg));
 	params = vala_signal_get_parameters (sig);
@@ -528,20 +528,19 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCC
 	_tmp17 = (g_free (_tmp17), NULL);
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = params;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
-				if (VALA_IS_POINTER_TYPE (vala_formal_parameter_get_type_reference (param)) || vala_data_type_get_type_parameter (vala_formal_parameter_get_type_reference (param)) != NULL || vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
+				if (VALA_IS_POINTER_TYPE (vala_formal_parameter_get_parameter_type (param)) || vala_data_type_get_type_parameter (vala_formal_parameter_get_parameter_type (param)) != NULL || vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
 					ValaCCodeConstant* _tmp19;
 					_tmp19 = NULL;
 					vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp19 = vala_ccode_constant_new ("G_TYPE_POINTER"))));
 					(_tmp19 == NULL ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL)));
 				} else {
-					if (VALA_IS_ERROR_TYPE (vala_formal_parameter_get_type_reference (param))) {
+					if (VALA_IS_ERROR_TYPE (vala_formal_parameter_get_parameter_type (param))) {
 						ValaCCodeConstant* _tmp20;
 						_tmp20 = NULL;
 						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_constant_new ("G_TYPE_POINTER"))));
@@ -551,7 +550,7 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCC
 						char* _tmp21;
 						_tmp22 = NULL;
 						_tmp21 = NULL;
-						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_constant_new ((_tmp21 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_formal_parameter_get_type_reference (param))))))));
+						vala_ccode_function_call_add_argument (csignew, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_constant_new ((_tmp21 = vala_typesymbol_get_type_id (vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (param))))))));
 						(_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL)));
 						_tmp21 = (g_free (_tmp21), NULL);
 					}
@@ -559,7 +558,6 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCC
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	vala_ccode_identifier_set_name (marshal_arg, marshaller);
 	_tmp23 = NULL;
@@ -567,29 +565,22 @@ ValaCCodeFunctionCall* vala_ccode_typesymbol_binding_get_signal_creation (ValaCC
 }
 
 
-ValaCCodeTypesymbolBinding* vala_ccode_typesymbol_binding_new (void) {
-	ValaCCodeTypesymbolBinding * self;
-	self = g_object_newv (VALA_TYPE_CCODE_TYPESYMBOL_BINDING, 0, NULL);
-	return self;
+static void vala_ccode_type_symbol_binding_class_init (ValaCCodeTypeSymbolBindingClass * klass) {
+	vala_ccode_type_symbol_binding_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_ccode_typesymbol_binding_class_init (ValaCCodeTypesymbolBindingClass * klass) {
-	vala_ccode_typesymbol_binding_parent_class = g_type_class_peek_parent (klass);
+static void vala_ccode_type_symbol_binding_instance_init (ValaCCodeTypeSymbolBinding * self) {
 }
 
 
-static void vala_ccode_typesymbol_binding_init (ValaCCodeTypesymbolBinding * self) {
-}
-
-
-GType vala_ccode_typesymbol_binding_get_type (void) {
-	static GType vala_ccode_typesymbol_binding_type_id = 0;
-	if (G_UNLIKELY (vala_ccode_typesymbol_binding_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeTypesymbolBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_typesymbol_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeTypesymbolBinding), 0, (GInstanceInitFunc) vala_ccode_typesymbol_binding_init };
-		vala_ccode_typesymbol_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_BINDING, "ValaCCodeTypesymbolBinding", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
+GType vala_ccode_type_symbol_binding_get_type (void) {
+	static GType vala_ccode_type_symbol_binding_type_id = 0;
+	if (G_UNLIKELY (vala_ccode_type_symbol_binding_type_id == 0)) {
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeTypeSymbolBindingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_type_symbol_binding_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeTypeSymbolBinding), 0, (GInstanceInitFunc) vala_ccode_type_symbol_binding_instance_init };
+		vala_ccode_type_symbol_binding_type_id = g_type_register_static (VALA_TYPE_CCODE_BINDING, "ValaCCodeTypeSymbolBinding", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
-	return vala_ccode_typesymbol_binding_type_id;
+	return vala_ccode_type_symbol_binding_type_id;
 }
 
 
