@@ -24,6 +24,9 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 enum  {
 	VALA_BREAK_STATEMENT_DUMMY_PROPERTY
 };
@@ -32,6 +35,7 @@ static gpointer vala_break_statement_parent_class = NULL;
 static ValaStatementIface* vala_break_statement_vala_statement_parent_iface = NULL;
 
 
+
 /**
  * Creates a new break statement.
  *
@@ -40,7 +44,7 @@ static ValaStatementIface* vala_break_statement_vala_statement_parent_iface = NU
  */
 ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
 	ValaBreakStatement * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_BREAK_STATEMENT, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
@@ -50,7 +54,7 @@ ValaBreakStatement* vala_break_statement_new (ValaSourceReference* source) {
 static void vala_break_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBreakStatement * self;
 	self = VALA_BREAK_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_break_statement (visitor, self);
 }
 
@@ -66,14 +70,14 @@ static void vala_break_statement_vala_statement_interface_init (ValaStatementIfa
 }
 
 
-static void vala_break_statement_init (ValaBreakStatement * self) {
+static void vala_break_statement_instance_init (ValaBreakStatement * self) {
 }
 
 
 GType vala_break_statement_get_type (void) {
 	static GType vala_break_statement_type_id = 0;
 	if (G_UNLIKELY (vala_break_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBreakStatement), 0, (GInstanceInitFunc) vala_break_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaBreakStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_break_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaBreakStatement), 0, (GInstanceInitFunc) vala_break_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_break_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_break_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaBreakStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_break_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
