@@ -27,6 +27,7 @@
 #include <gee/readonlylist.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valacodegenerator.h>
 
 
 
@@ -35,6 +36,7 @@ struct _ValaElementAccessPrivate {
 	ValaExpression* _container;
 	GeeList* indices;
 };
+
 #define VALA_ELEMENT_ACCESS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ELEMENT_ACCESS, ValaElementAccessPrivate))
 enum  {
 	VALA_ELEMENT_ACCESS_DUMMY_PROPERTY,
@@ -43,6 +45,7 @@ enum  {
 static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_element_access_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node);
 static gboolean vala_element_access_real_is_pure (ValaExpression* base);
+static ValaCodeBinding* vala_element_access_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_element_access_parent_class = NULL;
 static void vala_element_access_dispose (GObject * obj);
 
@@ -50,7 +53,7 @@ static void vala_element_access_dispose (GObject * obj);
 
 void vala_element_access_append_index (ValaElementAccess* self, ValaExpression* index) {
 	g_return_if_fail (VALA_IS_ELEMENT_ACCESS (self));
-	g_return_if_fail (index == NULL || VALA_IS_EXPRESSION (index));
+	g_return_if_fail (VALA_IS_EXPRESSION (index));
 	gee_collection_add (GEE_COLLECTION (self->priv->indices), index);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (index), VALA_CODE_NODE (self));
 }
@@ -58,17 +61,17 @@ void vala_element_access_append_index (ValaElementAccess* self, ValaExpression*
 
 GeeList* vala_element_access_get_indices (ValaElementAccess* self) {
 	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->indices));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->indices));
 }
 
 
 ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourceReference* source_reference) {
 	ValaElementAccess * self;
-	g_return_val_if_fail (container == NULL || VALA_IS_EXPRESSION (container), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (container), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ELEMENT_ACCESS, 0, NULL);
-	vala_element_access_set_container (self, container);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_element_access_set_container (self, container);
 	return self;
 }
 
@@ -76,24 +79,23 @@ ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourc
 static void vala_element_access_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaElementAccess * self;
 	self = VALA_ELEMENT_ACCESS (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_container), visitor);
 	{
 		GeeList* e_collection;
-		GeeIterator* e_it;
+		int e_it;
 		e_collection = self->priv->indices;
-		e_it = gee_iterable_iterator (GEE_ITERABLE (e_collection));
-		while (gee_iterator_next (e_it)) {
+		for (e_it = 0; e_it < gee_collection_get_size (GEE_COLLECTION (e_collection)); e_it = e_it + 1) {
 			ValaExpression* e;
-			e = ((ValaExpression*) gee_iterator_get (e_it));
+			e = ((ValaExpression*) (gee_list_get (GEE_LIST (e_collection), e_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (e), visitor);
 				(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
 			}
 		}
-		(e_it == NULL ? NULL : (e_it = (g_object_unref (e_it), NULL)));
 	}
 	vala_code_visitor_visit_element_access (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -101,14 +103,14 @@ static void vala_element_access_real_replace_expression (ValaCodeNode* base, Val
 	ValaElementAccess * self;
 	gint index;
 	self = VALA_ELEMENT_ACCESS (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (self->priv->_container == old_node) {
 		vala_element_access_set_container (self, new_node);
 	}
 	index = gee_list_index_of (self->priv->indices, old_node);
 	if (index >= 0 && vala_code_node_get_parent_node (VALA_CODE_NODE (new_node)) == NULL) {
-		gee_list_set (((GeeList*) self->priv->indices), index, new_node);
+		gee_list_set (((GeeList*) (self->priv->indices)), index, new_node);
 		vala_code_node_set_parent_node (VALA_CODE_NODE (new_node), VALA_CODE_NODE (self));
 	}
 }
@@ -119,26 +121,32 @@ static gboolean vala_element_access_real_is_pure (ValaExpression* base) {
 	self = VALA_ELEMENT_ACCESS (base);
 	{
 		GeeList* index_collection;
-		GeeIterator* index_it;
+		int index_it;
 		index_collection = self->priv->indices;
-		index_it = gee_iterable_iterator (GEE_ITERABLE (index_collection));
-		while (gee_iterator_next (index_it)) {
+		for (index_it = 0; index_it < gee_collection_get_size (GEE_COLLECTION (index_collection)); index_it = index_it + 1) {
 			ValaExpression* index;
-			index = ((ValaExpression*) gee_iterator_get (index_it));
+			index = ((ValaExpression*) (gee_list_get (GEE_LIST (index_collection), index_it)));
 			{
 				if (!vala_expression_is_pure (index)) {
 					gboolean _tmp0;
-					return (_tmp0 = FALSE, (index == NULL ? NULL : (index = (g_object_unref (index), NULL))), (index_it == NULL ? NULL : (index_it = (g_object_unref (index_it), NULL))), _tmp0);
+					return (_tmp0 = FALSE, (index == NULL ? NULL : (index = (g_object_unref (index), NULL))), _tmp0);
 				}
 				(index == NULL ? NULL : (index = (g_object_unref (index), NULL)));
 			}
 		}
-		(index_it == NULL ? NULL : (index_it = (g_object_unref (index_it), NULL)));
 	}
 	return vala_expression_is_pure (self->priv->_container);
 }
 
 
+static ValaCodeBinding* vala_element_access_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaElementAccess * self;
+	self = VALA_ELEMENT_ACCESS (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_element_access_binding (codegen, self);
+}
+
+
 ValaExpression* vala_element_access_get_container (ValaElementAccess* self) {
 	g_return_val_if_fail (VALA_IS_ELEMENT_ACCESS (self), NULL);
 	return self->priv->_container;
@@ -192,13 +200,14 @@ static void vala_element_access_class_init (ValaElementAccessClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_element_access_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_element_access_real_replace_expression;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_element_access_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_element_access_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ELEMENT_ACCESS_CONTAINER, g_param_spec_object ("container", "container", "container", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_element_access_init (ValaElementAccess * self) {
+static void vala_element_access_instance_init (ValaElementAccess * self) {
 	self->priv = VALA_ELEMENT_ACCESS_GET_PRIVATE (self);
-	self->priv->indices = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->indices = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -214,7 +223,7 @@ static void vala_element_access_dispose (GObject * obj) {
 GType vala_element_access_get_type (void) {
 	static GType vala_element_access_type_id = 0;
 	if (G_UNLIKELY (vala_element_access_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaElementAccess), 0, (GInstanceInitFunc) vala_element_access_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaElementAccessClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_element_access_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaElementAccess), 0, (GInstanceInitFunc) vala_element_access_instance_init };
 		vala_element_access_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaElementAccess", &g_define_type_info, 0);
 	}
 	return vala_element_access_type_id;
