@@ -1,6 +1,6 @@
 /* valafield.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -28,27 +28,30 @@
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaFieldPrivate {
-	ValaExpression* _initializer;
+	MemberBinding _binding;
 	gboolean _is_volatile;
 	gboolean _no_array_length;
 	char* cname;
-	gboolean _instance;
 	gboolean lock_used;
+	ValaExpression* _initializer;
 	ValaDataType* _data_type;
 };
+
 #define VALA_FIELD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FIELD, ValaFieldPrivate))
 enum  {
 	VALA_FIELD_DUMMY_PROPERTY,
-	VALA_FIELD_TYPE_REFERENCE,
+	VALA_FIELD_FIELD_TYPE,
 	VALA_FIELD_INITIALIZER,
-	VALA_FIELD_INSTANCE,
+	VALA_FIELD_BINDING,
 	VALA_FIELD_IS_VOLATILE,
 	VALA_FIELD_NO_ARRAY_LENGTH
 };
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static void vala_field_set_cname (ValaField* self, const char* cname);
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a);
 static gboolean vala_field_real_get_lock_used (ValaLockable* base);
 static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used);
@@ -60,6 +63,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new field.
  *
@@ -69,14 +73,15 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source reference to source code
  * @return       newly created field
  */
-ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
+ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaField * self;
-	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (field_type), NULL);
 	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_FIELD, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
-	vala_field_set_type_reference (self, type_reference);
+	vala_field_set_field_type (self, field_type);
 	vala_field_set_initializer (self, initializer);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
@@ -86,7 +91,7 @@ ValaField* vala_field_new (const char* name, ValaDataType* type_reference, ValaE
 static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
 	self = VALA_FIELD (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_field (visitor, self);
 }
@@ -95,8 +100,8 @@ static void vala_field_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_field_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaField * self;
 	self = VALA_FIELD (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_type_reference (self)), visitor);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (vala_field_get_field_type (self)), visitor);
 	if (vala_field_get_initializer (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_field_get_initializer (self)), visitor);
 	}
@@ -121,10 +126,16 @@ char* vala_field_get_cname (ValaField* self) {
 }
 
 
-static void vala_field_set_cname (ValaField* self, const char* cname) {
+/**
+ * Sets the name of this field as it is used in C code.
+ *
+ * @param cname the name to be used in C code
+ */
+void vala_field_set_cname (ValaField* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_FIELD (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -138,7 +149,7 @@ static void vala_field_set_cname (ValaField* self, const char* cname) {
  */
 char* vala_field_get_default_cname (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
-	if (!vala_field_get_instance (self)) {
+	if (self->priv->_binding == MEMBER_BINDING_STATIC) {
 		char* _tmp0;
 		char* _tmp1;
 		_tmp0 = NULL;
@@ -154,7 +165,7 @@ char* vala_field_get_default_cname (ValaField* self) {
 
 static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_FIELD (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -166,8 +177,8 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
 			char** filename_collection;
-			char** filename_it;
 			int filename_collection_length1;
+			char** filename_it;
 			filename_collection = g_strsplit (val, ",", 0);
 			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
@@ -180,7 +191,7 @@ static void vala_field_process_ccode_attribute (ValaField* self, ValaAttribute*
 					filename = (g_free (filename), NULL);
 				}
 			}
-			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) (g_free))), NULL);
 		}
 		val = (g_free (val), NULL);
 	}
@@ -200,7 +211,7 @@ void vala_field_process_attributes (ValaField* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_field_process_ccode_attribute (self, a);
@@ -233,21 +244,21 @@ static void vala_field_real_set_lock_used (ValaLockable* base, gboolean used) {
 static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaField * self;
 	self = VALA_FIELD (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
-	if (vala_field_get_type_reference (self) == old_type) {
-		vala_field_set_type_reference (self, new_type);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_field_get_field_type (self) == old_type) {
+		vala_field_set_field_type (self, new_type);
 	}
 }
 
 
-ValaDataType* vala_field_get_type_reference (ValaField* self) {
+ValaDataType* vala_field_get_field_type (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_field_set_type_reference (ValaField* self, ValaDataType* value) {
+void vala_field_set_field_type (ValaField* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_FIELD (self));
@@ -271,18 +282,21 @@ void vala_field_set_initializer (ValaField* self, ValaExpression* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
+	if (self->priv->_initializer != NULL) {
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_initializer), VALA_CODE_NODE (self));
+	}
 }
 
 
-gboolean vala_field_get_instance (ValaField* self) {
-	g_return_val_if_fail (VALA_IS_FIELD (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_field_get_binding (ValaField* self) {
+	g_return_val_if_fail (VALA_IS_FIELD (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_field_set_instance (ValaField* self, gboolean value) {
+void vala_field_set_binding (ValaField* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_FIELD (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
@@ -314,14 +328,14 @@ static void vala_field_get_property (GObject * object, guint property_id, GValue
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
-		case VALA_FIELD_TYPE_REFERENCE:
-		g_value_set_object (value, vala_field_get_type_reference (self));
+		case VALA_FIELD_FIELD_TYPE:
+		g_value_set_object (value, vala_field_get_field_type (self));
 		break;
 		case VALA_FIELD_INITIALIZER:
 		g_value_set_object (value, vala_field_get_initializer (self));
 		break;
-		case VALA_FIELD_INSTANCE:
-		g_value_set_boolean (value, vala_field_get_instance (self));
+		case VALA_FIELD_BINDING:
+		g_value_set_enum (value, vala_field_get_binding (self));
 		break;
 		case VALA_FIELD_IS_VOLATILE:
 		g_value_set_boolean (value, vala_field_get_is_volatile (self));
@@ -340,14 +354,14 @@ static void vala_field_set_property (GObject * object, guint property_id, const
 	ValaField * self;
 	self = VALA_FIELD (object);
 	switch (property_id) {
-		case VALA_FIELD_TYPE_REFERENCE:
-		vala_field_set_type_reference (self, g_value_get_object (value));
+		case VALA_FIELD_FIELD_TYPE:
+		vala_field_set_field_type (self, g_value_get_object (value));
 		break;
 		case VALA_FIELD_INITIALIZER:
 		vala_field_set_initializer (self, g_value_get_object (value));
 		break;
-		case VALA_FIELD_INSTANCE:
-		vala_field_set_instance (self, g_value_get_boolean (value));
+		case VALA_FIELD_BINDING:
+		vala_field_set_binding (self, g_value_get_enum (value));
 		break;
 		case VALA_FIELD_IS_VOLATILE:
 		vala_field_set_is_volatile (self, g_value_get_boolean (value));
@@ -371,9 +385,9 @@ static void vala_field_class_init (ValaFieldClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_field_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_field_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_field_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_FIELD_TYPE, g_param_spec_object ("field-type", "field-type", "field-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INITIALIZER, g_param_spec_object ("initializer", "initializer", "initializer", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_IS_VOLATILE, g_param_spec_boolean ("is-volatile", "is-volatile", "is-volatile", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FIELD_NO_ARRAY_LENGTH, g_param_spec_boolean ("no-array-length", "no-array-length", "no-array-length", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
@@ -386,9 +400,9 @@ static void vala_field_vala_lockable_interface_init (ValaLockableIface * iface)
 }
 
 
-static void vala_field_init (ValaField * self) {
+static void vala_field_instance_init (ValaField * self) {
 	self->priv = VALA_FIELD_GET_PRIVATE (self);
-	self->priv->_instance = TRUE;
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 	self->priv->lock_used = FALSE;
 }
 
@@ -396,8 +410,8 @@ static void vala_field_init (ValaField * self) {
 static void vala_field_dispose (GObject * obj) {
 	ValaField * self;
 	self = VALA_FIELD (obj);
-	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
+	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_field_parent_class)->dispose (obj);
 }
@@ -406,7 +420,7 @@ static void vala_field_dispose (GObject * obj) {
 GType vala_field_get_type (void) {
 	static GType vala_field_type_id = 0;
 	if (G_UNLIKELY (vala_field_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaFieldClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_field_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaField), 0, (GInstanceInitFunc) vala_field_instance_init };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_field_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_field_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaField", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_field_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
@@ -420,12 +434,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
