@@ -26,11 +26,15 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaMemberInitializerPrivate {
 	char* _name;
 	ValaExpression* _initializer;
 	ValaSymbol* _symbol_reference;
 };
+
 #define VALA_MEMBER_INITIALIZER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_MEMBER_INITIALIZER, ValaMemberInitializerPrivate))
 enum  {
 	VALA_MEMBER_INITIALIZER_DUMMY_PROPERTY,
@@ -43,6 +47,7 @@ static gpointer vala_member_initializer_parent_class = NULL;
 static void vala_member_initializer_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new member initializer.
  *
@@ -53,12 +58,13 @@ static void vala_member_initializer_dispose (GObject * obj);
  */
 ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaMemberInitializer * self;
-	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_MEMBER_INITIALIZER, 0, NULL);
-	vala_member_initializer_set_name (self, name);
 	vala_member_initializer_set_initializer (self, initializer);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_member_initializer_set_name (self, name);
 	return self;
 }
 
@@ -66,12 +72,12 @@ ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpres
 static void vala_member_initializer_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_member_initializer_get_initializer (self)), visitor);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
 }
 
 
-char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
+const char* vala_member_initializer_get_name (ValaMemberInitializer* self) {
 	g_return_val_if_fail (VALA_IS_MEMBER_INITIALIZER (self), NULL);
 	return self->priv->_name;
 }
@@ -168,7 +174,7 @@ static void vala_member_initializer_class_init (ValaMemberInitializerClass * kla
 }
 
 
-static void vala_member_initializer_init (ValaMemberInitializer * self) {
+static void vala_member_initializer_instance_init (ValaMemberInitializer * self) {
 	self->priv = VALA_MEMBER_INITIALIZER_GET_PRIVATE (self);
 }
 
@@ -176,7 +182,7 @@ static void vala_member_initializer_init (ValaMemberInitializer * self) {
 static void vala_member_initializer_dispose (GObject * obj) {
 	ValaMemberInitializer * self;
 	self = VALA_MEMBER_INITIALIZER (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	G_OBJECT_CLASS (vala_member_initializer_parent_class)->dispose (obj);
 }
@@ -185,7 +191,7 @@ static void vala_member_initializer_dispose (GObject * obj) {
 GType vala_member_initializer_get_type (void) {
 	static GType vala_member_initializer_type_id = 0;
 	if (G_UNLIKELY (vala_member_initializer_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberInitializerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_initializer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberInitializer), 0, (GInstanceInitFunc) vala_member_initializer_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaMemberInitializerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_member_initializer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaMemberInitializer), 0, (GInstanceInitFunc) vala_member_initializer_instance_init };
 		vala_member_initializer_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaMemberInitializer", &g_define_type_info, 0);
 	}
 	return vala_member_initializer_type_id;
