@@ -22,35 +22,37 @@
 
 #include <vala/valasignal.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valaformalparameter.h>
-#include <vala/valadelegate.h>
+#include <vala/valamethod.h>
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
-#include <vala/valareferencetype.h>
-#include <vala/valaclass.h>
-#include <vala/valaclasstype.h>
-#include <vala/valainterfacetype.h>
-#include <vala/valainterface.h>
+#include <vala/valadelegate.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaSignalPrivate {
 	gboolean _has_emitter;
+	gboolean _is_virtual;
 	GeeList* parameters;
-	ValaDelegate* generated_delegate;
+	ValaMethod* generated_method;
 	char* cname;
 	gboolean lock_used;
 	ValaDataType* _return_type;
 };
+
 #define VALA_SIGNAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL, ValaSignalPrivate))
 enum  {
 	VALA_SIGNAL_DUMMY_PROPERTY,
 	VALA_SIGNAL_RETURN_TYPE,
-	VALA_SIGNAL_HAS_EMITTER
+	VALA_SIGNAL_HAS_EMITTER,
+	VALA_SIGNAL_IS_VIRTUAL
 };
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -60,6 +62,8 @@ static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old
 static gpointer vala_signal_parent_class = NULL;
 static ValaLockableIface* vala_signal_vala_lockable_parent_iface = NULL;
 static void vala_signal_dispose (GObject * obj);
+static int _vala_strcmp0 (const char * str1, const char * str2);
+
 
 
 /**
@@ -72,12 +76,13 @@ static void vala_signal_dispose (GObject * obj);
  */
 ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaSignal * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SIGNAL, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_signal_set_return_type (self, return_type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -89,15 +94,19 @@ ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSo
  */
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_SIGNAL (self));
-	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
+	/* default C parameter position*/
+	vala_formal_parameter_set_cparameter_position (param, ((double) (gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1)));
+	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
+	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (param)), VALA_SYMBOL (param));
 }
 
 
-GeeCollection* vala_signal_get_parameters (ValaSignal* self) {
+GeeList* vala_signal_get_parameters (ValaSignal* self) {
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->parameters)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->parameters));
 }
 
 
@@ -106,48 +115,37 @@ GeeCollection* vala_signal_get_parameters (ValaSignal* self) {
  *
  * @return delegate
  */
-ValaDelegate* vala_signal_get_delegate (ValaSignal* self) {
-	ValaDelegate* _tmp3;
+ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_type) {
+	ValaDelegate* generated_delegate;
+	ValaDataType* sender_param_type;
+	ValaFormalParameter* sender_param;
+	ValaDelegate* _tmp0;
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
-	if (self->priv->generated_delegate == NULL) {
-		ValaDelegate* _tmp0;
-		ValaReferenceType* sender_type;
-		ValaFormalParameter* sender_param;
-		_tmp0 = NULL;
-		self->priv->generated_delegate = (_tmp0 = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL), (self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL))), _tmp0);
-		vala_delegate_set_instance (self->priv->generated_delegate, TRUE);
-		sender_type = NULL;
-		if (VALA_IS_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
-			ValaReferenceType* _tmp1;
-			_tmp1 = NULL;
-			sender_type = (_tmp1 = VALA_REFERENCE_TYPE (vala_class_type_new (VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp1);
-		} else {
-			ValaReferenceType* _tmp2;
-			_tmp2 = NULL;
-			sender_type = (_tmp2 = VALA_REFERENCE_TYPE (vala_interface_type_new (VALA_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))))), (sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL))), _tmp2);
-		}
-		sender_param = vala_formal_parameter_new ("sender", VALA_DATA_TYPE (sender_type), NULL);
-		vala_delegate_add_parameter (self->priv->generated_delegate, sender_param);
-		{
-			GeeList* param_collection;
-			GeeIterator* param_it;
-			param_collection = self->priv->parameters;
-			param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-			while (gee_iterator_next (param_it)) {
-				ValaFormalParameter* param;
-				param = gee_iterator_get (param_it);
-				{
-					vala_delegate_add_parameter (self->priv->generated_delegate, param);
-					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
-				}
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (sender_type), NULL);
+	generated_delegate = vala_delegate_new (NULL, vala_signal_get_return_type (self), NULL);
+	vala_delegate_set_has_target (generated_delegate, TRUE);
+	/* sender parameter is never null and doesn't own its value*/
+	sender_param_type = vala_data_type_copy (sender_type);
+	vala_data_type_set_value_owned (sender_param_type, FALSE);
+	vala_data_type_set_nullable (sender_param_type, FALSE);
+	sender_param = vala_formal_parameter_new ("_sender", sender_param_type, NULL);
+	vala_delegate_add_parameter (generated_delegate, sender_param);
+	{
+		GeeList* param_collection;
+		int param_it;
+		param_collection = self->priv->parameters;
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
+			ValaFormalParameter* param;
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
+			{
+				vala_delegate_add_parameter (generated_delegate, param);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
-			(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 		}
-		(sender_type == NULL ? NULL : (sender_type = (g_object_unref (sender_type), NULL)));
-		(sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL)));
 	}
-	_tmp3 = NULL;
-	return (_tmp3 = self->priv->generated_delegate, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), NULL, VALA_SYMBOL (generated_delegate));
+	_tmp0 = NULL;
+	return (_tmp0 = generated_delegate, (sender_param_type == NULL ? NULL : (sender_param_type = (g_object_unref (sender_param_type), NULL))), (sender_param == NULL ? NULL : (sender_param = (g_object_unref (sender_param), NULL))), _tmp0);
 }
 
 
@@ -175,6 +173,7 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_SIGNAL (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -218,7 +217,7 @@ ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
 static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_signal (visitor, self);
 }
@@ -227,22 +226,20 @@ static void vala_signal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_signal_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_signal_get_return_type (self)), visitor);
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = gee_iterator_get (param_it);
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 }
 
@@ -260,9 +257,9 @@ void vala_signal_process_attributes (ValaSignal* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = a_it->data, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
-				if (g_utf8_collate (vala_attribute_get_name (a), "HasEmitter") == 0) {
+				if (_vala_strcmp0 (vala_attribute_get_name (a), "HasEmitter") == 0) {
 					vala_signal_set_has_emitter (self, TRUE);
 				}
 				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
@@ -289,14 +286,44 @@ static void vala_signal_real_set_lock_used (ValaLockable* base, gboolean used) {
 static void vala_signal_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_signal_get_return_type (self) == old_type) {
 		vala_signal_set_return_type (self, new_type);
 	}
 }
 
 
+ValaMethod* vala_signal_get_method_handler (ValaSignal* self) {
+	ValaMethod* _tmp1;
+	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
+	g_assert (self->priv->_is_virtual);
+	if (self->priv->generated_method == NULL) {
+		ValaMethod* _tmp0;
+		_tmp0 = NULL;
+		self->priv->generated_method = (_tmp0 = vala_method_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_signal_get_return_type (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->generated_method == NULL ? NULL : (self->priv->generated_method = (g_object_unref (self->priv->generated_method), NULL))), _tmp0);
+		vala_method_set_is_virtual (self->priv->generated_method, TRUE);
+		vala_method_set_vfunc_name (self->priv->generated_method, vala_symbol_get_name (VALA_SYMBOL (self)));
+		{
+			GeeList* param_collection;
+			int param_it;
+			param_collection = self->priv->parameters;
+			for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
+				ValaFormalParameter* param;
+				param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
+				{
+					vala_method_add_parameter (self->priv->generated_method, param);
+					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+				}
+			}
+		}
+		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))), NULL, VALA_SYMBOL (self->priv->generated_method));
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->generated_method, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+}
+
+
 ValaDataType* vala_signal_get_return_type (ValaSignal* self) {
 	g_return_val_if_fail (VALA_IS_SIGNAL (self), NULL);
 	return self->priv->_return_type;
@@ -326,6 +353,18 @@ void vala_signal_set_has_emitter (ValaSignal* self, gboolean value) {
 }
 
 
+gboolean vala_signal_get_is_virtual (ValaSignal* self) {
+	g_return_val_if_fail (VALA_IS_SIGNAL (self), FALSE);
+	return self->priv->_is_virtual;
+}
+
+
+void vala_signal_set_is_virtual (ValaSignal* self, gboolean value) {
+	g_return_if_fail (VALA_IS_SIGNAL (self));
+	self->priv->_is_virtual = value;
+}
+
+
 static void vala_signal_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (object);
@@ -336,6 +375,9 @@ static void vala_signal_get_property (GObject * object, guint property_id, GValu
 		case VALA_SIGNAL_HAS_EMITTER:
 		g_value_set_boolean (value, vala_signal_get_has_emitter (self));
 		break;
+		case VALA_SIGNAL_IS_VIRTUAL:
+		g_value_set_boolean (value, vala_signal_get_is_virtual (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -353,6 +395,9 @@ static void vala_signal_set_property (GObject * object, guint property_id, const
 		case VALA_SIGNAL_HAS_EMITTER:
 		vala_signal_set_has_emitter (self, g_value_get_boolean (value));
 		break;
+		case VALA_SIGNAL_IS_VIRTUAL:
+		vala_signal_set_is_virtual (self, g_value_get_boolean (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -371,6 +416,7 @@ static void vala_signal_class_init (ValaSignalClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_signal_real_replace_type;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_HAS_EMITTER, g_param_spec_boolean ("has-emitter", "has-emitter", "has-emitter", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SIGNAL_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -381,9 +427,9 @@ static void vala_signal_vala_lockable_interface_init (ValaLockableIface * iface)
 }
 
 
-static void vala_signal_init (ValaSignal * self) {
+static void vala_signal_instance_init (ValaSignal * self) {
 	self->priv = VALA_SIGNAL_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	self->priv->lock_used = FALSE;
 }
 
@@ -392,8 +438,8 @@ static void vala_signal_dispose (GObject * obj) {
 	ValaSignal * self;
 	self = VALA_SIGNAL (obj);
 	(self->priv->parameters == NULL ? NULL : (self->priv->parameters = (g_object_unref (self->priv->parameters), NULL)));
-	(self->priv->generated_delegate == NULL ? NULL : (self->priv->generated_delegate = (g_object_unref (self->priv->generated_delegate), NULL)));
-	(self->priv->cname = (g_free (self->priv->cname), NULL));
+	(self->priv->generated_method == NULL ? NULL : (self->priv->generated_method = (g_object_unref (self->priv->generated_method), NULL)));
+	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_return_type == NULL ? NULL : (self->priv->_return_type = (g_object_unref (self->priv->_return_type), NULL)));
 	G_OBJECT_CLASS (vala_signal_parent_class)->dispose (obj);
 }
@@ -402,7 +448,7 @@ static void vala_signal_dispose (GObject * obj) {
 GType vala_signal_get_type (void) {
 	static GType vala_signal_type_id = 0;
 	if (G_UNLIKELY (vala_signal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSignalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_signal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSignal), 0, (GInstanceInitFunc) vala_signal_instance_init };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_signal_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_signal_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaSignal", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_signal_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
@@ -411,5 +457,16 @@ GType vala_signal_get_type (void) {
 }
 
 
+static int _vala_strcmp0 (const char * str1, const char * str2) {
+	if (str1 == NULL) {
+		return -(str1 != str2);
+	}
+	if (str2 == NULL) {
+		return (str1 != str2);
+	}
+	return strcmp (str1, str2);
+}
+
+
 
 
