@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <ccode/valaccodeconstant.h>
 #include <vala/valamember.h>
 #include <vala/valalockable.h>
@@ -52,24 +52,30 @@ struct _ValaSignal {
 	ValaMember parent_instance;
 	ValaSignalPrivate * priv;
 };
+
 struct _ValaSignalClass {
 	ValaMemberClass parent_class;
 };
 
+
 ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference);
 void vala_signal_add_parameter (ValaSignal* self, ValaFormalParameter* param);
-GeeCollection* vala_signal_get_parameters (ValaSignal* self);
-ValaDelegate* vala_signal_get_delegate (ValaSignal* self);
+GeeList* vala_signal_get_parameters (ValaSignal* self);
+ValaDelegate* vala_signal_get_delegate (ValaSignal* self, ValaDataType* sender_type);
 char* vala_signal_get_cname (ValaSignal* self);
 void vala_signal_set_cname (ValaSignal* self, const char* cname);
 ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self);
 void vala_signal_process_attributes (ValaSignal* self);
+ValaMethod* vala_signal_get_method_handler (ValaSignal* self);
 ValaDataType* vala_signal_get_return_type (ValaSignal* self);
 void vala_signal_set_return_type (ValaSignal* self, ValaDataType* value);
 gboolean vala_signal_get_has_emitter (ValaSignal* self);
 void vala_signal_set_has_emitter (ValaSignal* self, gboolean value);
+gboolean vala_signal_get_is_virtual (ValaSignal* self);
+void vala_signal_set_is_virtual (ValaSignal* self, gboolean value);
 GType vala_signal_get_type (void);
 
+
 G_END_DECLS
 
 #endif
