@@ -23,6 +23,7 @@
 #include <vala/valastringliteral.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaexpression.h>
 
 
 
@@ -75,7 +76,7 @@ char* vala_string_literal_eval (ValaStringLiteral* self) {
 		return NULL;
 	}
 	/* remove quotes */
-	noquotes = g_strndup (g_utf8_offset_to_pointer (self->priv->_value, ((glong) 1)), ((gulong) ((guint) (g_utf8_strlen (self->priv->_value, -1) - 2))));
+	noquotes = g_strndup (g_utf8_offset_to_pointer (self->priv->_value, ((glong) (1))), ((gulong) (((guint) ((g_utf8_strlen (self->priv->_value, -1) - 2))))));
 	/* unescape string */
 	_tmp1 = NULL;
 	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
@@ -87,6 +88,7 @@ static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor
 	self = VALA_STRING_LITERAL (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_string_literal (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -106,7 +108,7 @@ static char* vala_string_literal_real_to_string (ValaCodeNode* base) {
 }
 
 
-char* vala_string_literal_get_value (ValaStringLiteral* self) {
+const char* vala_string_literal_get_value (ValaStringLiteral* self) {
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	return self->priv->_value;
 }
@@ -163,7 +165,7 @@ static void vala_string_literal_class_init (ValaStringLiteralClass * klass) {
 }
 
 
-static void vala_string_literal_init (ValaStringLiteral * self) {
+static void vala_string_literal_instance_init (ValaStringLiteral * self) {
 	self->priv = VALA_STRING_LITERAL_GET_PRIVATE (self);
 }
 
@@ -179,7 +181,7 @@ static void vala_string_literal_dispose (GObject * obj) {
 GType vala_string_literal_get_type (void) {
 	static GType vala_string_literal_type_id = 0;
 	if (G_UNLIKELY (vala_string_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaStringLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_string_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStringLiteral), 0, (GInstanceInitFunc) vala_string_literal_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaStringLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_string_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStringLiteral), 0, (GInstanceInitFunc) vala_string_literal_instance_init };
 		vala_string_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaStringLiteral", &g_define_type_info, 0);
 	}
 	return vala_string_literal_type_id;
