@@ -1,6 +1,6 @@
 /* valatrystatement.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valacodenode.h>
 #include <vala/valastatement.h>
 
@@ -48,19 +48,22 @@ struct _ValaTryStatement {
 	ValaCodeNode parent_instance;
 	ValaTryStatementPrivate * priv;
 };
+
 struct _ValaTryStatementClass {
 	ValaCodeNodeClass parent_class;
 };
 
+
 ValaTryStatement* vala_try_statement_new (ValaBlock* body, ValaBlock* finally_body, ValaSourceReference* source_reference);
 void vala_try_statement_add_catch_clause (ValaTryStatement* self, ValaCatchClause* clause);
-GeeCollection* vala_try_statement_get_catch_clauses (ValaTryStatement* self);
+GeeList* vala_try_statement_get_catch_clauses (ValaTryStatement* self);
 ValaBlock* vala_try_statement_get_body (ValaTryStatement* self);
 void vala_try_statement_set_body (ValaTryStatement* self, ValaBlock* value);
 ValaBlock* vala_try_statement_get_finally_body (ValaTryStatement* self);
 void vala_try_statement_set_finally_body (ValaTryStatement* self, ValaBlock* value);
 GType vala_try_statement_get_type (void);
 
+
 G_END_DECLS
 
 #endif
