@@ -29,8 +29,8 @@
 #include <string.h>
 #include <gee/arraylist.h>
 #include <gee/hashset.h>
-#include <gidlmodule.h>
 #include <gidlparser.h>
+#include <gidlmodule.h>
 #include <stdio.h>
 #include <gee/collection.h>
 #include <gidlnode.h>
@@ -103,33 +103,36 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context) {
 	GParameter * __params;
 	GParameter * __params_it;
-	ValaSourceFile* _tmp0;
-	ValaSourceFile* _tmp4;
+	ValaSourceFile* _tmp1;
+	ValaCodeContext* _tmp0;
+	ValaSourceFile* _tmp5;
+	char* _tmp4;
 	char* _tmp3;
 	char* _tmp2;
-	char* _tmp1;
 	ValaVAPICheck * self;
 	g_return_val_if_fail (gidlname != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
+	_tmp1 = NULL;
 	_tmp0 = NULL;
 	__params_it->name = "gidl";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	g_value_set_object (&__params_it->value, (_tmp0 = vala_source_file_new (context, gidlname, FALSE)));
+	g_value_set_object (&__params_it->value, (_tmp1 = vala_source_file_new (context, gidlname, FALSE)));
 	__params_it++;
+	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
+	_tmp5 = NULL;
 	_tmp4 = NULL;
 	_tmp3 = NULL;
 	_tmp2 = NULL;
-	_tmp1 = NULL;
 	__params_it->name = "metadata";
 	g_value_init (&__params_it->value, VALA_TYPE_SOURCE_FILE);
-	g_value_set_object (&__params_it->value, (_tmp4 = vala_source_file_new (context, (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (gidlname, ((glong) 0)), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2)), ".metadata", NULL)), FALSE)));
+	g_value_set_object (&__params_it->value, (_tmp5 = vala_source_file_new (context, (_tmp4 = g_strconcat ((_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (gidlname, ((glong) (0))), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidlname, -1) - 5) - _tmp2))), ".metadata", NULL)), FALSE)));
 	__params_it++;
-	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+	(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
+	_tmp4 = (g_free (_tmp4), NULL);
 	_tmp3 = (g_free (_tmp3), NULL);
-	_tmp1 = (g_free (_tmp1), NULL);
 	__params_it->name = "context";
 	g_value_init (&__params_it->value, VALA_TYPE_CODE_CONTEXT);
 	g_value_set_object (&__params_it->value, context);
@@ -145,7 +148,7 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 
 
 static void _g_list_free_g_idl_module_free (GList* self) {
-	g_list_foreach (self, ((GFunc) g_idl_module_free), NULL);
+	g_list_foreach (self, ((GFunc) (g_idl_module_free)), NULL);
 	g_list_free (self);
 }
 
@@ -157,9 +160,9 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
 	inner_error = NULL;
 	_tmp0 = NULL;
-	self->priv->_scope = (_tmp0 = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal)), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL))), _tmp0);
+	self->priv->_scope = (_tmp0 = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal)), (self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL))), _tmp0);
 	_tmp1 = NULL;
-	self->priv->_symbols = (_tmp1 = GEE_SET (gee_hash_set_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_hash, g_str_equal)), (self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (g_object_unref (self->priv->_symbols), NULL))), _tmp1);
+	self->priv->_symbols = (_tmp1 = GEE_SET (gee_hash_set_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_hash, g_str_equal)), (self->priv->_symbols == NULL ? NULL : (self->priv->_symbols = (g_object_unref (self->priv->_symbols), NULL))), _tmp1);
 	{
 		{
 			GList* module_collection;
@@ -174,7 +177,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 			}
 			for (module_it = module_collection; module_it != NULL; module_it = module_it->next) {
 				GIdlModule* module;
-				module = ((GIdlModule*) module_it->data);
+				module = ((GIdlModule*) (module_it->data));
 				{
 					vala_vapi_check_parse_members (self, module->name, module->entries);
 				}
@@ -219,7 +222,7 @@ static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, c
 
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
 	g_return_val_if_fail (VALA_IS_VAPI_CHECK (self), NULL);
-	return ((char*) gee_list_get (((GeeList*) self->priv->_scope), gee_collection_get_size (GEE_COLLECTION (self->priv->_scope)) - 1));
+	return ((char*) (gee_list_get (((GeeList*) (self->priv->_scope)), gee_collection_get_size (GEE_COLLECTION (self->priv->_scope)) - 1)));
 }
 
 
@@ -248,25 +251,25 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 		node_collection = members;
 		for (node_it = node_collection; node_it != NULL; node_it = node_it->next) {
 			GIdlNode* node;
-			node = ((GIdlNode*) node_it->data);
+			node = ((GIdlNode*) (node_it->data));
 			{
 				GIdlNodeTypeId _tmp0;
 				_tmp0 = node->type;
 				if (_tmp0 == G_IDL_NODE_ENUM)
 				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeEnum*) node))->gtype_name, (((GIdlNodeEnum*) node))->values);
+					vala_vapi_check_parse_members (self, (((GIdlNodeEnum*) (node)))->gtype_name, (((GIdlNodeEnum*) (node)))->values);
 					break;
 				} while (0); else if (_tmp0 == G_IDL_NODE_FUNCTION)
 				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeFunction*) node))->symbol, (((GIdlNodeFunction*) node))->parameters);
+					vala_vapi_check_parse_members (self, (((GIdlNodeFunction*) (node)))->symbol, (((GIdlNodeFunction*) (node)))->parameters);
 					break;
 				} while (0); else if (_tmp0 == G_IDL_NODE_BOXED)
 				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeBoxed*) node))->gtype_name, (((GIdlNodeBoxed*) node))->members);
+					vala_vapi_check_parse_members (self, (((GIdlNodeBoxed*) (node)))->gtype_name, (((GIdlNodeBoxed*) (node)))->members);
 					break;
 				} while (0); else if (_tmp0 == G_IDL_NODE_INTERFACE || _tmp0 == G_IDL_NODE_OBJECT)
 				do {
-					vala_vapi_check_parse_members (self, (((GIdlNodeInterface*) node))->gtype_name, (((GIdlNodeInterface*) node))->members);
+					vala_vapi_check_parse_members (self, (((GIdlNodeInterface*) (node)))->gtype_name, (((GIdlNodeInterface*) (node)))->members);
 					break;
 				} while (0); else if (_tmp0 == G_IDL_NODE_FIELD || _tmp0 == G_IDL_NODE_PARAM)
 				do {
@@ -278,7 +281,7 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 					break;
 				} while (0); else if (_tmp0 == G_IDL_NODE_STRUCT)
 				do {
-					vala_vapi_check_parse_members (self, node->name, (((GIdlNodeStruct*) node))->members);
+					vala_vapi_check_parse_members (self, node->name, (((GIdlNodeStruct*) (node)))->members);
 					break;
 				} while (0); else if (_tmp0 == G_IDL_NODE_VALUE || _tmp0 == G_IDL_NODE_VFUNC)
 				do {
@@ -303,9 +306,10 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		GIOChannel* metafile;
 		char* line;
 		gint lineno;
+		char* _tmp2;
 		GIOStatus _tmp1;
 		char* _tmp0;
-		gint _tmp5;
+		gint _tmp6;
 		metafile = g_io_channel_new_file (vala_source_file_get_filename (self->priv->_metadata), "r", &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
@@ -316,31 +320,32 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		}
 		line = NULL;
 		lineno = 1;
+		_tmp2 = NULL;
 		_tmp0 = NULL;
-		while (G_IO_STATUS_NORMAL == (_tmp1 = g_io_channel_read_line (metafile, &_tmp0, NULL, NULL, &inner_error), (line = (g_free (line), NULL)), line = _tmp0, _tmp1)) {
-			char** _tmp2;
+		while (G_IO_STATUS_NORMAL == (_tmp1 = g_io_channel_read_line (metafile, &_tmp0, NULL, NULL, &inner_error), line = (_tmp2 = _tmp0, (line = (g_free (line), NULL)), _tmp2), _tmp1)) {
+			char** _tmp3;
 			gint tokens_length1;
 			char** tokens;
-			const char* _tmp3;
+			const char* _tmp4;
 			char* symbol;
-			_tmp2 = NULL;
-			tokens = (_tmp2 = g_strsplit (line, " ", 2), tokens_length1 = -1, _tmp2);
 			_tmp3 = NULL;
-			symbol = (_tmp3 = tokens[0], (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+			tokens = (_tmp3 = g_strsplit (line, " ", 2), tokens_length1 = -1, _tmp3);
+			_tmp4 = NULL;
+			symbol = (_tmp4 = tokens[0], (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 			if (strlen (symbol) > 0 && !gee_collection_contains (GEE_COLLECTION (self->priv->_symbols), symbol)) {
 				ValaSourceReference* src;
-				char* _tmp4;
-				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, ((gint) g_utf8_strlen (symbol, -1)));
-				_tmp4 = NULL;
-				vala_report_error (src, (_tmp4 = g_strdup_printf ("Symbol `%s' not found", symbol)));
-				_tmp4 = (g_free (_tmp4), NULL);
+				char* _tmp5;
+				src = vala_source_reference_new (self->priv->_metadata, lineno, 1, lineno, ((gint) (g_utf8_strlen (symbol, -1))));
+				_tmp5 = NULL;
+				vala_report_error (src, (_tmp5 = g_strdup_printf ("Symbol `%s' not found", symbol)));
+				_tmp5 = (g_free (_tmp5), NULL);
 				(src == NULL ? NULL : (src = (g_object_unref (src), NULL)));
 			}
 			lineno = lineno + (1);
-			tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) g_free)), NULL);
+			tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) (g_free))), NULL);
 			symbol = (g_free (symbol), NULL);
 		}
-		return (_tmp5 = 0, (metafile == NULL ? NULL : (metafile = (g_io_channel_unref (metafile), NULL))), (line = (g_free (line), NULL)), _tmp5);
+		return (_tmp6 = 0, (metafile == NULL ? NULL : (metafile = (g_io_channel_unref (metafile), NULL))), (line = (g_free (line), NULL)), _tmp6);
 	}
 	goto __finally1;
 	__catch1_g_file_error:
@@ -349,10 +354,10 @@ static gint vala_vapi_check_check_metadata (ValaVAPICheck* self) {
 		error = inner_error;
 		inner_error = NULL;
 		{
-			char* _tmp6;
-			_tmp6 = NULL;
-			vala_report_error (NULL, (_tmp6 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message)));
-			_tmp6 = (g_free (_tmp6), NULL);
+			char* _tmp7;
+			_tmp7 = NULL;
+			vala_report_error (NULL, (_tmp7 = g_strdup_printf ("%s: %s", vala_source_file_get_filename (self->priv->_metadata), error->message)));
+			_tmp7 = (g_free (_tmp7), NULL);
 			return 1;
 		}
 	}
@@ -383,8 +388,10 @@ static gint vala_vapi_check_run (ValaVAPICheck* self) {
 
 
 static gint vala_vapi_check_main (char** args, int args_length1) {
+	ValaCodeContext* _tmp2;
+	ValaVAPICheck* _tmp3;
 	ValaVAPICheck* vapicheck;
-	gint _tmp2;
+	gint _tmp4;
 	if (2 != args_length1 || !g_str_has_suffix (args[1], ".gidl")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -392,8 +399,10 @@ static gint vala_vapi_check_main (char** args, int args_length1) {
 		_tmp0 = (g_free (_tmp0), NULL);
 		return 2;
 	}
-	vapicheck = vala_vapi_check_new (args[1], vala_code_context_new ());
-	return (_tmp2 = vala_vapi_check_run (vapicheck), (vapicheck == NULL ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL))), _tmp2);
+	_tmp2 = NULL;
+	_tmp3 = NULL;
+	vapicheck = (_tmp3 = vala_vapi_check_new (args[1], (_tmp2 = vala_code_context_new ())), (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3);
+	return (_tmp4 = vala_vapi_check_run (vapicheck), (vapicheck == NULL ? NULL : (vapicheck = (g_object_unref (vapicheck), NULL))), _tmp4);
 }
 
 
@@ -503,7 +512,7 @@ static void vala_vapi_check_class_init (ValaVAPICheckClass * klass) {
 }
 
 
-static void vala_vapi_check_init (ValaVAPICheck * self) {
+static void vala_vapi_check_instance_init (ValaVAPICheck * self) {
 	self->priv = VALA_VAPI_CHECK_GET_PRIVATE (self);
 }
 
@@ -523,7 +532,7 @@ static void vala_vapi_check_dispose (GObject * obj) {
 static GType vala_vapi_check_get_type (void) {
 	static GType vala_vapi_check_type_id = 0;
 	if (G_UNLIKELY (vala_vapi_check_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPICheckClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_check_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPICheck), 0, (GInstanceInitFunc) vala_vapi_check_instance_init };
 		vala_vapi_check_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaVAPICheck", &g_define_type_info, 0);
 	}
 	return vala_vapi_check_type_id;
@@ -535,12 +544,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
