@@ -52,14 +52,17 @@ struct _ValaVAPIGen {
 	GObject parent_instance;
 	ValaVAPIGenPrivate * priv;
 };
+
 struct _ValaVAPIGenClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _ValaVAPIGenPrivate {
 	ValaCodeContext* context;
 };
+
 #define VALA_VAPI_GEN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VAPI_GEN, ValaVAPIGenPrivate))
 enum  {
 	VALA_VAPI_GEN_DUMMY_PROPERTY
@@ -82,7 +85,7 @@ static void vala_vapi_gen_dispose (GObject * obj);
 static GType vala_vapi_gen_get_type (void);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 
-static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", ((gchar) 0), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", ((gchar) 0), 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", ((gchar) 0), 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", ((gchar) 0), 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", ((gchar) 0), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
+static const GOptionEntry VALA_VAPI_GEN_options[] = {{"vapidir", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_vapi_directories, "Look for package bindings in DIRECTORY", "DIRECTORY..."}, {"pkg", ((gchar) (0)), 0, G_OPTION_ARG_STRING_ARRAY, &vala_vapi_gen_packages, "Include binding for PACKAGE", "PACKAGE..."}, {"library", ((gchar) (0)), 0, G_OPTION_ARG_STRING, &vala_vapi_gen_library, "Library name", "NAME"}, {"directory", 'd', 0, G_OPTION_ARG_FILENAME, &vala_vapi_gen_directory, "Output directory", "DIRECTORY"}, {"version", ((gchar) (0)), 0, G_OPTION_ARG_NONE, &vala_vapi_gen_version, "Display version number", NULL}, {"quiet", 'q', 0, G_OPTION_ARG_NONE, &vala_vapi_gen_quiet_mode, "Do not print messages to the console", NULL}, {"", ((gchar) (0)), 0, G_OPTION_ARG_FILENAME_ARRAY, &vala_vapi_gen_sources, NULL, "FILE..."}, {NULL}};
 
 
 static gint vala_vapi_gen_quit (ValaVAPIGen* self) {
@@ -106,10 +109,11 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 	ValaSourceFile* _tmp2;
 	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_VAPI_GEN (self), FALSE);
+	g_return_val_if_fail (pkg != NULL, FALSE);
 	if (vala_code_context_has_package (self->priv->context, pkg)) {
+		/* ignore multiple occurences of the same package*/
 		return TRUE;
 	}
-	/* ignore multiple occurences of the same package*/
 	package_path = vala_code_context_get_package_path (self->priv->context, pkg, -1, vala_vapi_gen_vapi_directories);
 	if (package_path == NULL) {
 		gboolean _tmp1;
@@ -125,22 +129,46 @@ static gboolean vala_vapi_gen_add_package (ValaVAPIGen* self, const char* pkg) {
 
 static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, int* result_length1) {
 	GError * inner_error;
-	char* contents;
-	gboolean _tmp1;
-	char* _tmp0;
-	gpointer _tmp4;
-	gpointer _tmp5;
+	g_return_val_if_fail (depsfile != NULL, NULL);
 	inner_error = NULL;
-	contents = NULL;
-	_tmp0 = NULL;
-	if ((_tmp1 = g_file_get_contents (depsfile, &_tmp0, NULL, &inner_error), (contents = (g_free (contents), NULL)), contents = _tmp0, _tmp1)) {
-		char** _tmp2;
+	{
+		char* contents;
+		char* _tmp2;
+		gboolean _tmp1;
+		char* _tmp0;
 		char** _tmp3;
+		char** _tmp4;
+		contents = NULL;
 		_tmp2 = NULL;
+		_tmp0 = NULL;
+		_tmp1 = g_file_get_contents (depsfile, &_tmp0, NULL, &inner_error);
+		contents = (_tmp2 = _tmp0, (contents = (g_free (contents), NULL)), _tmp2);
+		_tmp1;
+		if (inner_error != NULL) {
+			if (inner_error->domain == G_FILE_ERROR) {
+				goto __catch2_g_file_error;
+			}
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+			g_clear_error (&inner_error);
+		}
 		_tmp3 = NULL;
-		return (_tmp3 = (_tmp2 = g_strsplit (g_strstrip (contents), "\n", 0), *result_length1 = -1, _tmp2), (contents = (g_free (contents), NULL)), _tmp3);
+		_tmp4 = NULL;
+		return (_tmp4 = (_tmp3 = g_strsplit (g_strstrip (contents), "\n", 0), (*result_length1) = -1, _tmp3), (contents = (g_free (contents), NULL)), _tmp4);
 	}
-	return (_tmp5 = (_tmp4 = NULL, *result_length1 = 0, _tmp4), (contents = (g_free (contents), NULL)), _tmp5);
+	goto __finally2;
+	__catch2_g_file_error:
+	{
+		GError * e;
+		e = inner_error;
+		inner_error = NULL;
+		{
+			gpointer _tmp5;
+			/* deps files are optional*/
+			return (_tmp5 = NULL, (*result_length1) = 0, _tmp5);
+		}
+	}
+	__finally2:
+	;
 }
 
 
@@ -159,10 +187,11 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 	if (!vala_vapi_gen_add_package (self, "glib-2.0")) {
 		vala_report_error (NULL, "glib-2.0 not found in specified Vala API directories");
 	}
+	/* load packages from .deps file */
 	{
 		char** source_collection;
-		char** source_it;
 		int source_collection_length1;
+		char** source_it;
 		source_collection = vala_vapi_gen_sources;
 		source_collection_length1 = -1;
 		for (source_it = source_collection; *source_it != NULL; source_it = source_it + 1) {
@@ -179,7 +208,6 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				gint deps_length1;
 				gint _tmp4;
 				char** deps;
-				/* load packages from .deps file */
 				if (!g_str_has_suffix (source, ".gi")) {
 					source = (g_free (source), NULL);
 					continue;
@@ -187,7 +215,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				_tmp2 = NULL;
 				_tmp1 = NULL;
 				_tmp3 = NULL;
-				depsfile = (_tmp3 = g_strconcat ((_tmp2 = g_utf8_offset_to_pointer (source, ((glong) 0)), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)) - _tmp2)), "deps", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp3);
+				depsfile = (_tmp3 = g_strconcat ((_tmp2 = (_tmp1 = g_utf8_offset_to_pointer (source, ((glong) (0))), g_strndup (_tmp1, g_utf8_offset_to_pointer (_tmp1, g_utf8_strlen (source, -1) - g_utf8_strlen ("gi", -1)) - _tmp1))), "deps", NULL), (_tmp2 = (g_free (_tmp2), NULL)), _tmp3);
 				if (!g_file_test (depsfile, G_FILE_TEST_EXISTS)) {
 					source = (g_free (source), NULL);
 					depsfile = (g_free (depsfile), NULL);
@@ -197,8 +225,10 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				deps = (_tmp5 = vala_vapi_gen_get_packages_from_depsfile (depsfile, &_tmp4), deps_length1 = _tmp4, _tmp5);
 				{
 					char** dep_collection;
+					int dep_collection_length1;
 					int dep_it;
 					dep_collection = deps;
+					dep_collection_length1 = deps_length1;
 					for (dep_it = 0; (deps_length1 != -1 && dep_it < deps_length1) || (deps_length1 == -1 && dep_collection[dep_it] != NULL); dep_it = dep_it + 1) {
 						const char* _tmp7;
 						char* dep;
@@ -217,7 +247,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 				}
 				source = (g_free (source), NULL);
 				depsfile = (g_free (depsfile), NULL);
-				deps = (_vala_array_free (deps, deps_length1, ((GDestroyNotify) g_free)), NULL);
+				deps = (_vala_array_free (deps, deps_length1, ((GDestroyNotify) (g_free))), NULL);
 			}
 		}
 	}
@@ -225,8 +255,8 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		char** _tmp11;
 		{
 			char** package_collection;
-			char** package_it;
 			int package_collection_length1;
+			char** package_it;
 			package_collection = vala_vapi_gen_packages;
 			package_collection_length1 = -1;
 			for (package_it = package_collection; *package_it != NULL; package_it = package_it + 1) {
@@ -246,15 +276,15 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 			}
 		}
 		_tmp11 = NULL;
-		vala_vapi_gen_packages = (_tmp11 = NULL, (vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, -1, ((GDestroyNotify) g_free)), NULL)), _tmp11);
+		vala_vapi_gen_packages = (_tmp11 = NULL, (vala_vapi_gen_packages = (_vala_array_free (vala_vapi_gen_packages, -1, ((GDestroyNotify) (g_free))), NULL)), _tmp11);
 	}
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
 	}
 	{
 		char** source_collection;
-		char** source_it;
 		int source_collection_length1;
+		char** source_it;
 		source_collection = vala_vapi_gen_sources;
 		source_collection_length1 = -1;
 		for (source_it = source_collection; *source_it != NULL; source_it = source_it + 1) {
@@ -279,7 +309,7 @@ static gint vala_vapi_gen_run (ValaVAPIGen* self) {
 		}
 	}
 	_tmp16 = NULL;
-	vala_vapi_gen_sources = (_tmp16 = NULL, (vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, -1, ((GDestroyNotify) g_free)), NULL)), _tmp16);
+	vala_vapi_gen_sources = (_tmp16 = NULL, (vala_vapi_gen_sources = (_vala_array_free (vala_vapi_gen_sources, -1, ((GDestroyNotify) (g_free))), NULL)), _tmp16);
 	if (vala_report_get_errors () > 0) {
 		return vala_vapi_gen_quit (self);
 	}
@@ -336,15 +366,15 @@ static gint vala_vapi_gen_main (char** args, int args_length1) {
 		g_option_context_parse (opt_context, &args_length1, &args, &inner_error);
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_OPTION_ERROR) {
-				goto __catch2_g_option_error;
+				goto __catch3_g_option_error;
 			}
 			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
 			g_clear_error (&inner_error);
 		}
 		(opt_context == NULL ? NULL : (opt_context = (g_option_context_free (opt_context), NULL)));
 	}
-	goto __finally2;
-	__catch2_g_option_error:
+	goto __finally3;
+	__catch3_g_option_error:
 	{
 		GError * e;
 		e = inner_error;
@@ -355,7 +385,7 @@ static gint vala_vapi_gen_main (char** args, int args_length1) {
 			return 1;
 		}
 	}
-	__finally2:
+	__finally3:
 	;
 	if (vala_vapi_gen_version) {
 		fprintf (stdout, "Vala API Generator %s\n", PACKAGE_VERSION);
@@ -390,7 +420,7 @@ static void vala_vapi_gen_class_init (ValaVAPIGenClass * klass) {
 }
 
 
-static void vala_vapi_gen_init (ValaVAPIGen * self) {
+static void vala_vapi_gen_instance_init (ValaVAPIGen * self) {
 	self->priv = VALA_VAPI_GEN_GET_PRIVATE (self);
 }
 
@@ -406,7 +436,7 @@ static void vala_vapi_gen_dispose (GObject * obj) {
 static GType vala_vapi_gen_get_type (void) {
 	static GType vala_vapi_gen_type_id = 0;
 	if (G_UNLIKELY (vala_vapi_gen_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaVAPIGenClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_vapi_gen_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaVAPIGen), 0, (GInstanceInitFunc) vala_vapi_gen_instance_init };
 		vala_vapi_gen_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaVAPIGen", &g_define_type_info, 0);
 	}
 	return vala_vapi_gen_type_id;
@@ -418,12 +448,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
